#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 22 15:51:00 2018

@author: patrickmcfarlane

test_player.py

This function contains the tests for
functions in the player.py file
"""

import time

from .__init__ import HEADERS
from ..player import Player

def test_playercareer():
    """ tests the playercareerstats	 endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            player_id='203954')

    table_names = example_player.data.keys()

    assert 'SeasonTotalsRegularSeason' in table_names
    assert 'CareerTotalsRegularSeason' in table_names
    assert 'SeasonTotalsPostSeason' in table_names
    assert 'CareerTotalsPostSeason' in table_names
    assert 'SeasonTotalsAllStarSeason' in table_names
    assert 'CareerTotalsAllStarSeason' in table_names
    assert 'SeasonTotalsCollegeSeason' in table_names
    assert 'CareerTotalsCollegeSeason' in table_names
    assert 'SeasonRankingsRegularSeason' in table_names
    assert 'SeasonRankingsPostSeason' in table_names

    example_season_reg = example_player.data['SeasonTotalsRegularSeason'][0]
    example_career_reg = example_player.data['CareerTotalsRegularSeason'][0]
    example_season_post = example_player.data['SeasonTotalsPostSeason'][0]
    example_career_post = example_player.data['CareerTotalsPostSeason'][0]
    example_season_star = example_player.data['SeasonTotalsAllStarSeason'][0]
    example_career_star = example_player.data['CareerTotalsAllStarSeason'][0]
    example_season_col = example_player.data['SeasonTotalsCollegeSeason'][0]
    example_career_col = example_player.data['CareerTotalsCollegeSeason'][0]
    example_seasonrank_reg = example_player.data['SeasonRankingsRegularSeason'][0]
    example_seasonrank_post = example_player.data['SeasonRankingsPostSeason'][0]

    assert list(example_season_reg.keys()) == ['PLAYER_ID',
                                               'SEASON_ID',
                                               'LEAGUE_ID',
                                               'TEAM_ID',
                                               'TEAM_ABBREVIATION',
                                               'PLAYER_AGE',
                                               'GP',
                                               'GS',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'STL',
                                               'BLK',
                                               'TOV',
                                               'PF',
                                               'PTS']

    assert list(example_career_reg.keys()) == ['PLAYER_ID',
                                               'LEAGUE_ID',
                                               'Team_ID',
                                               'GP',
                                               'GS',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'STL',
                                               'BLK',
                                               'TOV',
                                               'PF',
                                               'PTS']

    assert list(example_season_post.keys()) == ['PLAYER_ID',
                                                'SEASON_ID',
                                                'LEAGUE_ID',
                                                'TEAM_ID',
                                                'TEAM_ABBREVIATION',
                                                'PLAYER_AGE',
                                                'GP',
                                                'GS',
                                                'MIN',
                                                'FGM',
                                                'FGA',
                                                'FG_PCT',
                                                'FG3M',
                                                'FG3A',
                                                'FG3_PCT',
                                                'FTM',
                                                'FTA',
                                                'FT_PCT',
                                                'OREB',
                                                'DREB',
                                                'REB',
                                                'AST',
                                                'STL',
                                                'BLK',
                                                'TOV',
                                                'PF',
                                                'PTS']

    assert list(example_career_post.keys()) == ['PLAYER_ID',
                                                'LEAGUE_ID',
                                                'Team_ID',
                                                'GP',
                                                'GS',
                                                'MIN',
                                                'FGM',
                                                'FGA',
                                                'FG_PCT',
                                                'FG3M',
                                                'FG3A',
                                                'FG3_PCT',
                                                'FTM',
                                                'FTA',
                                                'FT_PCT',
                                                'OREB',
                                                'DREB',
                                                'REB',
                                                'AST',
                                                'STL',
                                                'BLK',
                                                'TOV',
                                                'PF',
                                                'PTS']

    assert list(example_season_star.keys()) == ['PLAYER_ID',
                                                'SEASON_ID',
                                                'LEAGUE_ID',
                                                'TEAM_ID',
                                                'TEAM_ABBREVIATION',
                                                'PLAYER_AGE',
                                                'GP',
                                                'GS',
                                                'MIN',
                                                'FGM',
                                                'FGA',
                                                'FG_PCT',
                                                'FG3M',
                                                'FG3A',
                                                'FG3_PCT',
                                                'FTM',
                                                'FTA',
                                                'FT_PCT',
                                                'OREB',
                                                'DREB',
                                                'REB',
                                                'AST',
                                                'STL',
                                                'BLK',
                                                'TOV',
                                                'PF',
                                                'PTS']

    assert list(example_career_star.keys()) == ['PLAYER_ID',
                                                'LEAGUE_ID',
                                                'Team_ID',
                                                'GP',
                                                'GS',
                                                'MIN',
                                                'FGM',
                                                'FGA',
                                                'FG_PCT',
                                                'FG3M',
                                                'FG3A',
                                                'FG3_PCT',
                                                'FTM',
                                                'FTA',
                                                'FT_PCT',
                                                'OREB',
                                                'DREB',
                                                'REB',
                                                'AST',
                                                'STL',
                                                'BLK',
                                                'TOV',
                                                'PF',
                                                'PTS']

    assert list(example_season_col.keys()) == ['PLAYER_ID',
                                               'SEASON_ID',
                                               'LEAGUE_ID',
                                               'ORGANIZATION_ID',
                                               'SCHOOL_NAME',
                                               'PLAYER_AGE',
                                               'GP',
                                               'GS',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'STL',
                                               'BLK',
                                               'TOV',
                                               'PF',
                                               'PTS']

    assert list(example_career_col.keys()) == ['PLAYER_ID',
                                               'LEAGUE_ID',
                                               'ORGANIZATION_ID',
                                               'GP',
                                               'GS',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'STL',
                                               'BLK',
                                               'TOV',
                                               'PF',
                                               'PTS']

    assert list(example_seasonrank_reg.keys()) == ['PLAYER_ID',
                                                   'SEASON_ID',
                                                   'LEAGUE_ID',
                                                   'TEAM_ID',
                                                   'TEAM_ABBREVIATION',
                                                   'PLAYER_AGE',
                                                   'GP',
                                                   'GS',
                                                   'RANK_PG_MIN',
                                                   'RANK_PG_FGM',
                                                   'RANK_PG_FGA',
                                                   'RANK_FG_PCT',
                                                   'RANK_PG_FG3M',
                                                   'RANK_PG_FG3A',
                                                   'RANK_FG3_PCT',
                                                   'RANK_PG_FTM',
                                                   'RANK_PG_FTA',
                                                   'RANK_FT_PCT',
                                                   'RANK_PG_OREB',
                                                   'RANK_PG_DREB',
                                                   'RANK_PG_REB',
                                                   'RANK_PG_AST',
                                                   'RANK_PG_STL',
                                                   'RANK_PG_BLK',
                                                   'RANK_PG_TOV',
                                                   'RANK_PG_PTS',
                                                   'RANK_PG_EFF']

    assert list(example_seasonrank_post.keys()) == ['PLAYER_ID',
                                                    'SEASON_ID',
                                                    'LEAGUE_ID',
                                                    'TEAM_ID',
                                                    'TEAM_ABBREVIATION',
                                                    'PLAYER_AGE',
                                                    'GP',
                                                    'GS',
                                                    'RANK_PG_MIN',
                                                    'RANK_PG_FGM',
                                                    'RANK_PG_FGA',
                                                    'RANK_FG_PCT',
                                                    'RANK_PG_FG3M',
                                                    'RANK_PG_FG3A',
                                                    'RANK_FG3_PCT',
                                                    'RANK_PG_FTM',
                                                    'RANK_PG_FTA',
                                                    'RANK_FT_PCT',
                                                    'RANK_PG_OREB',
                                                    'RANK_PG_DREB',
                                                    'RANK_PG_REB',
                                                    'RANK_PG_AST',
                                                    'RANK_PG_STL',
                                                    'RANK_PG_BLK',
                                                    'RANK_PG_TOV',
                                                    'RANK_PG_PTS',
                                                    'RANK_PG_EFF']

def test_playercompare():
    """ tests the playercompare endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playercompare')

    table_names = example_player.data.keys()

    assert 'OverallCompare' in table_names
    assert 'Individual' in table_names

    example_overall = example_player.data['OverallCompare'][0]
    example_individual = example_player.data['Individual'][0]

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'DESCRIPTION',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS']

    assert list(example_individual.keys()) == ['GROUP_SET',
                                               'DESCRIPTION',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'TOV',
                                               'STL',
                                               'BLK',
                                               'BLKA',
                                               'PF',
                                               'PFD',
                                               'PTS',
                                               'PLUS_MINUS']

def test_player_clutch():
    """ tests the playerdashboardbyclutch endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbyclutch')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'Last5Min5PointPlayerDashboard' in table_names
    assert 'Last3Min5PointPlayerDashboard' in table_names
    assert 'Last1Min5PointPlayerDashboard' in table_names
    assert 'Last30Sec3PointPlayerDashboard' in table_names
    assert 'Last10Sec3PointPlayerDashboard' in table_names
    assert 'Last5MinPlusMinus5PointPlayerDashboard' in table_names
    assert 'Last3MinPlusMinus5PointPlayerDashboard' in table_names
    assert 'Last1MinPlusMinus5PointPlayerDashboard' in table_names
    assert 'Last30Sec3Point2PlayerDashboard' in table_names
    assert 'Last10Sec3Point2PlayerDashboard' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_last5_5 = example_player.data['Last5Min5PointPlayerDashboard'][0]
    example_last3_5 = example_player.data['Last3Min5PointPlayerDashboard'][0]
    example_last1_5 = example_player.data['Last1Min5PointPlayerDashboard'][0]
    example_last30_3 = example_player.data['Last30Sec3PointPlayerDashboard'][0]
    example_last10_3 = example_player.data['Last10Sec3PointPlayerDashboard'][0]
    example_last5 = example_player.data['Last5MinPlusMinus5PointPlayerDashboard'][0]
    example_last3 = example_player.data['Last3MinPlusMinus5PointPlayerDashboard'][0]
    example_last1 = example_player.data['Last1MinPlusMinus5PointPlayerDashboard'][0]
    example_last30_3_2 = example_player.data['Last30Sec3Point2PlayerDashboard'][0]
    example_last10_3_2 = example_player.data['Last10Sec3Point2PlayerDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'NBA_FANTASY_PTS',
               'DD2',
               'TD3',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'NBA_FANTASY_PTS_RANK',
               'DD2_RANK',
               'TD3_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_last5_5.keys()) == columns

    assert list(example_last3_5.keys()) == columns

    assert list(example_last1_5.keys()) == columns

    assert list(example_last30_3.keys()) == columns

    assert list(example_last10_3.keys()) == columns

    assert list(example_last5.keys()) == columns

    assert list(example_last3.keys()) == columns

    assert list(example_last1.keys()) == columns

    assert list(example_last30_3_2.keys()) == columns

    assert list(example_last10_3_2.keys()) == columns


def test_player_gamesplits():
    """ tests the playerdashboardbygamesplits endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbygamesplits')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'ByHalfPlayerDashboard' in table_names
    assert 'ByPeriodPlayerDashboard' in table_names
    assert 'ByScoreMarginPlayerDashboard' in table_names
    assert 'ByActualMarginPlayerDashboard' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_half = example_player.data['ByHalfPlayerDashboard'][0]
    example_period = example_player.data['ByPeriodPlayerDashboard'][0]
    example_score = example_player.data['ByScoreMarginPlayerDashboard'][0]
    example_margin = example_player.data['ByActualMarginPlayerDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'NBA_FANTASY_PTS',
               'DD2',
               'TD3',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'NBA_FANTASY_PTS_RANK',
               'DD2_RANK',
               'TD3_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_half.keys()) == columns

    assert list(example_period.keys()) == columns

    assert list(example_score.keys()) == columns

    assert list(example_margin.keys()) == columns

def test_player_generalsplits():
    """ tests the playerdashboardbygeneralsplits endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbygeneralsplits')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'LocationPlayerDashboard' in table_names
    assert 'WinsLossesPlayerDashboard' in table_names
    assert 'MonthPlayerDashboard' in table_names
    assert 'PrePostAllStarPlayerDashboard' in table_names
    assert 'StartingPosition' in table_names
    assert 'DaysRestPlayerDashboard' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_location = example_player.data['LocationPlayerDashboard'][0]
    example_wl = example_player.data['WinsLossesPlayerDashboard'][0]
    example_month = example_player.data['MonthPlayerDashboard'][0]
    example_star = example_player.data['PrePostAllStarPlayerDashboard'][0]
    example_starter = example_player.data['StartingPosition'][0]
    example_rest = example_player.data['DaysRestPlayerDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'NBA_FANTASY_PTS',
               'DD2',
               'TD3',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'NBA_FANTASY_PTS_RANK',
               'DD2_RANK',
               'TD3_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_location.keys()) == columns

    assert list(example_wl.keys()) == columns

    assert list(example_month.keys()) == columns

    assert list(example_star.keys()) == columns

    assert list(example_starter.keys()) == columns

    assert list(example_rest.keys()) == columns

def test_player_lastngames():
    """ tests the playerdashboardbylastngames endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbylastngames')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'Last5PlayerDashboard' in table_names
    assert 'Last10PlayerDashboard' in table_names
    assert 'Last15PlayerDashboard' in table_names
    assert 'Last20PlayerDashboard' in table_names
    assert 'GameNumberPlayerDashboard' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_last5 = example_player.data['Last5PlayerDashboard'][0]
    example_last10 = example_player.data['Last10PlayerDashboard'][0]
    example_last15 = example_player.data['Last15PlayerDashboard'][0]
    example_last20 = example_player.data['Last20PlayerDashboard'][0]
    example_game = example_player.data['GameNumberPlayerDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'NBA_FANTASY_PTS',
               'DD2',
               'TD3',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'NBA_FANTASY_PTS_RANK',
               'DD2_RANK',
               'TD3_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_last5.keys()) == columns

    assert list(example_last10.keys()) == columns

    assert list(example_last15.keys()) == columns

    assert list(example_last20.keys()) == columns

    assert list(example_game.keys()) == columns
    
def test_player_opponent():
    """ tests the playerdashboardbyopponent endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbyopponent')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'ConferencePlayerDashboard' in table_names
    assert 'DivisionPlayerDashboard' in table_names
    assert 'OpponentPlayerDashboard' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_conference = example_player.data['ConferencePlayerDashboard'][0]
    example_division = example_player.data['DivisionPlayerDashboard'][0]
    example_opponent = example_player.data['OpponentPlayerDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'NBA_FANTASY_PTS',
               'DD2',
               'TD3',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'NBA_FANTASY_PTS_RANK',
               'DD2_RANK',
               'TD3_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_conference.keys()) == columns

    assert list(example_division.keys()) == columns

    assert list(example_opponent.keys()) == columns

def test_player_shootingsplits():
    """ tests the playerdashboardbyshootingsplits endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbyshootingsplits')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'Shot5FTPlayerDashboard' in table_names
    assert 'Shot8FTPlayerDashboard' in table_names
    assert 'ShotAreaPlayerDashboard' in table_names
    assert 'AssitedShotPlayerDashboard' in table_names
    assert 'ShotTypeSummaryPlayerDashboard' in table_names
    assert 'ShotTypePlayerDashboard' in table_names
    assert 'AssistedBy' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_5ft = example_player.data['Shot5FTPlayerDashboard'][0]
    example_8ft = example_player.data['Shot8FTPlayerDashboard'][0]
    example_area = example_player.data['ShotAreaPlayerDashboard'][0]
    example_assisted = example_player.data['AssitedShotPlayerDashboard'][0]
    example_typesummary = example_player.data['ShotTypeSummaryPlayerDashboard'][0]
    example_type = example_player.data['ShotTypePlayerDashboard'][0]
    example_assistedby = example_player.data['AssistedBy'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'EFG_PCT',
               'BLKA',
               'PCT_AST_2PM',
               'PCT_UAST_2PM',
               'PCT_AST_3PM',
               'PCT_UAST_3PM',
               'PCT_AST_FGM',
               'PCT_UAST_FGM',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'EFG_PCT_RANK',
               'BLKA_RANK',
               'PCT_AST_2PM_RANK',
               'PCT_UAST_2PM_RANK',
               'PCT_AST_3PM_RANK',
               'PCT_UAST_3PM_RANK',
               'PCT_AST_FGM_RANK',
               'PCT_UAST_FGM_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns

    assert list(example_5ft.keys()) == columns

    assert list(example_8ft.keys()) == columns

    assert list(example_area.keys()) == columns

    assert list(example_assisted.keys()) == columns

    assert list(example_typesummary.keys()) == ['GROUP_SET',
                                                'GROUP_VALUE',
                                                'FGM',
                                                'FGA',
                                                'FG_PCT',
                                                'FG3M',
                                                'FG3A',
                                                'FG3_PCT',
                                                'EFG_PCT',
                                                'BLKA',
                                                'PCT_AST_2PM',
                                                'PCT_UAST_2PM',
                                                'PCT_AST_3PM',
                                                'PCT_UAST_3PM',
                                                'PCT_AST_FGM',
                                                'PCT_UAST_FGM',
                                                'CFID',
                                                'CFPARAMS']

    assert list(example_type.keys()) == columns

    assert list(example_assistedby.keys()) == ['GROUP_SET',
                                               'PLAYER_ID',
                                               'PLAYER_NAME',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'EFG_PCT',
                                               'BLKA',
                                               'PCT_AST_2PM',
                                               'PCT_UAST_2PM',
                                               'PCT_AST_3PM',
                                               'PCT_UAST_3PM',
                                               'PCT_AST_FGM',
                                               'PCT_UAST_FGM',
                                               'FGM_RANK',
                                               'FGA_RANK',
                                               'FG_PCT_RANK',
                                               'FG3M_RANK',
                                               'FG3A_RANK',
                                               'FG3_PCT_RANK',
                                               'EFG_PCT_RANK',
                                               'BLKA_RANK',
                                               'PCT_AST_2PM_RANK',
                                               'PCT_UAST_2PM_RANK',
                                               'PCT_AST_3PM_RANK',
                                               'PCT_UAST_3PM_RANK',
                                               'PCT_AST_FGM_RANK',
                                               'PCT_UAST_FGM_RANK',
                                               'CFID',
                                               'CFPARAMS']

def test_player_teamperformance():
    """ tests the playerdashboardbyteamperformance endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbyteamperformance')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'ScoreDifferentialPlayerDashboard' in table_names
    assert 'PointsScoredPlayerDashboard' in table_names
    assert 'PontsAgainstPlayerDashboard' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_scorediff = example_player.data['ScoreDifferentialPlayerDashboard'][0]
    example_scored = example_player.data['PointsScoredPlayerDashboard'][0]
    example_against = example_player.data['PontsAgainstPlayerDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE_ORDER',
               'GROUP_VALUE',
               'GROUP_VALUE_2',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'NBA_FANTASY_PTS',
               'DD2',
               'TD3',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'NBA_FANTASY_PTS_RANK',
               'DD2_RANK',
               'TD3_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'GROUP_VALUE',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'NBA_FANTASY_PTS',
                                            'DD2',
                                            'TD3',
                                            'GP_RANK',
                                            'W_RANK',
                                            'L_RANK',
                                            'W_PCT_RANK',
                                            'MIN_RANK',
                                            'FGM_RANK',
                                            'FGA_RANK',
                                            'FG_PCT_RANK',
                                            'FG3M_RANK',
                                            'FG3A_RANK',
                                            'FG3_PCT_RANK',
                                            'FTM_RANK',
                                            'FTA_RANK',
                                            'FT_PCT_RANK',
                                            'OREB_RANK',
                                            'DREB_RANK',
                                            'REB_RANK',
                                            'AST_RANK',
                                            'TOV_RANK',
                                            'STL_RANK',
                                            'BLK_RANK',
                                            'BLKA_RANK',
                                            'PF_RANK',
                                            'PFD_RANK',
                                            'PTS_RANK',
                                            'PLUS_MINUS_RANK',
                                            'NBA_FANTASY_PTS_RANK',
                                            'DD2_RANK',
                                            'TD3_RANK',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_scorediff.keys()) == columns

    assert list(example_scored.keys()) == columns

    assert list(example_against.keys()) == columns

def test_player_yoy():
    """ tests the playerdashboardbyyearoveryear endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashboardbyyearoveryear')

    table_names = example_player.data.keys()

    assert 'OverallPlayerDashboard' in table_names
    assert 'ByYearPlayerDashboard' in table_names

    example_overall = example_player.data['OverallPlayerDashboard'][0]
    example_yoy = example_player.data['ByYearPlayerDashboard'][0]

    columns = ['GROUP_SET',
               'GROUP_VALUE',
               'TEAM_ID',
               'TEAM_ABBREVIATION',
               'MAX_GAME_DATE',
               'GP',
               'W',
               'L',
               'W_PCT',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'TOV',
               'STL',
               'BLK',
               'BLKA',
               'PF',
               'PFD',
               'PTS',
               'PLUS_MINUS',
               'NBA_FANTASY_PTS',
               'DD2',
               'TD3',
               'GP_RANK',
               'W_RANK',
               'L_RANK',
               'W_PCT_RANK',
               'MIN_RANK',
               'FGM_RANK',
               'FGA_RANK',
               'FG_PCT_RANK',
               'FG3M_RANK',
               'FG3A_RANK',
               'FG3_PCT_RANK',
               'FTM_RANK',
               'FTA_RANK',
               'FT_PCT_RANK',
               'OREB_RANK',
               'DREB_RANK',
               'REB_RANK',
               'AST_RANK',
               'TOV_RANK',
               'STL_RANK',
               'BLK_RANK',
               'BLKA_RANK',
               'PF_RANK',
               'PFD_RANK',
               'PTS_RANK',
               'PLUS_MINUS_RANK',
               'NBA_FANTASY_PTS_RANK',
               'DD2_RANK',
               'TD3_RANK',
               'CFID',
               'CFPARAMS']

    assert list(example_overall.keys()) == columns
    assert list(example_yoy.keys()) == columns

def test_player_pass():
    """ tests the playerdashptpass endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashptpass')

    table_names = example_player.data.keys()

    assert 'PassesMade' in table_names
    assert 'PassesReceived' in table_names

    example_made = example_player.data['PassesMade'][0]
    example_received = example_player.data['PassesReceived'][0]

    assert list(example_made.keys()) == ['PLAYER_ID',
                                         'PLAYER_NAME_LAST_FIRST',
                                         'TEAM_NAME',
                                         'TEAM_ID',
                                         'TEAM_ABBREVIATION',
                                         'PASS_TYPE',
                                         'G',
                                         'PASS_TO',
                                         'PASS_TEAMMATE_PLAYER_ID',
                                         'FREQUENCY',
                                         'PASS',
                                         'AST',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'FG2M',
                                         'FG2A',
                                         'FG2_PCT',
                                         'FG3M',
                                         'FG3A',
                                         'FG3_PCT']

    assert list(example_received.keys()) == ['PLAYER_ID',
                                             'PLAYER_NAME_LAST_FIRST',
                                             'TEAM_NAME',
                                             'TEAM_ID',
                                             'TEAM_ABBREVIATION',
                                             'PASS_TYPE',
                                             'G',
                                             'PASS_FROM',
                                             'PASS_TEAMMATE_PLAYER_ID',
                                             'FREQUENCY',
                                             'PASS',
                                             'AST',
                                             'FGM',
                                             'FGA',
                                             'FG_PCT',
                                             'FG2M',
                                             'FG2A',
                                             'FG2_PCT',
                                             'FG3M',
                                             'FG3A',
                                             'FG3_PCT']

def test_player_reb():
    """ tests the playerdashptreb endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashptreb')

    table_names = example_player.data.keys()

    assert 'OverallRebounding' in table_names
    assert 'ShotTypeRebounding' in table_names
    assert 'NumContestedRebounding' in table_names
    assert 'ShotDistanceRebounding' in table_names
    assert 'RebDistanceRebounding' in table_names

    example_overall = example_player.data['OverallRebounding'][0]
    example_type = example_player.data['ShotTypeRebounding'][0]
    example_num = example_player.data['NumContestedRebounding'][0]
    example_shotdist = example_player.data['ShotDistanceRebounding'][0]
    example_rebdist = example_player.data['RebDistanceRebounding'][0]

    assert list(example_overall.keys()) == ['PLAYER_ID',
                                            'PLAYER_NAME_LAST_FIRST',
                                            'G',
                                            'OVERALL',
                                            'REB_FREQUENCY',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'C_OREB',
                                            'C_DREB',
                                            'C_REB',
                                            'C_REB_PCT',
                                            'UC_OREB',
                                            'UC_DREB',
                                            'UC_REB',
                                            'UC_REB_PCT']

    assert list(example_type.keys()) == ['PLAYER_ID',
                                         'PLAYER_NAME_LAST_FIRST',
                                         'SORT_ORDER',
                                         'G',
                                         'SHOT_TYPE_RANGE',
                                         'REB_FREQUENCY',
                                         'OREB',
                                         'DREB',
                                         'REB',
                                         'C_OREB',
                                         'C_DREB',
                                         'C_REB',
                                         'C_REB_PCT',
                                         'UC_OREB',
                                         'UC_DREB',
                                         'UC_REB',
                                         'UC_REB_PCT']

    assert list(example_num.keys()) == ['PLAYER_ID',
                                        'PLAYER_NAME_LAST_FIRST',
                                        'SORT_ORDER',
                                        'G',
                                        'REB_NUM_CONTESTING_RANGE',
                                        'REB_FREQUENCY',
                                        'OREB',
                                        'DREB',
                                        'REB',
                                        'C_OREB',
                                        'C_DREB',
                                        'C_REB',
                                        'C_REB_PCT',
                                        'UC_OREB',
                                        'UC_DREB',
                                        'UC_REB',
                                        'UC_REB_PCT']

    assert list(example_shotdist.keys()) == ['PLAYER_ID',
                                             'PLAYER_NAME_LAST_FIRST',
                                             'SORT_ORDER',
                                             'G',
                                             'SHOT_DIST_RANGE',
                                             'REB_FREQUENCY',
                                             'OREB',
                                             'DREB',
                                             'REB',
                                             'C_OREB',
                                             'C_DREB',
                                             'C_REB',
                                             'C_REB_PCT',
                                             'UC_OREB',
                                             'UC_DREB',
                                             'UC_REB',
                                             'UC_REB_PCT']

    assert list(example_rebdist.keys()) == ['PLAYER_ID',
                                           'PLAYER_NAME_LAST_FIRST',
                                           'SORT_ORDER',
                                           'G',
                                           'REB_DIST_RANGE',
                                           'REB_FREQUENCY',
                                           'OREB',
                                           'DREB',
                                           'REB',
                                           'C_OREB',
                                           'C_DREB',
                                           'C_REB',
                                           'C_REB_PCT',
                                           'UC_OREB',
                                           'UC_DREB',
                                           'UC_REB',
                                           'UC_REB_PCT']

def test_player_defend():
    """ tests the playerdashptshotdefend endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashptshotdefend')

    table_names = example_player.data.keys()

    assert 'DefendingShots' in table_names

    example_defend = example_player.data['DefendingShots'][0]

    assert list(example_defend.keys()) == ['CLOSE_DEF_PERSON_ID',
                                           'GP',
                                           'G',
                                           'DEFENSE_CATEGORY',
                                           'FREQ',
                                           'D_FGM',
                                           'D_FGA',
                                           'D_FG_PCT',
                                           'NORMAL_FG_PCT',
                                           'PCT_PLUSMINUS']

def test_player_shot():
    """ tests the playerdashptshots endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playerdashptshots')

    table_names = example_player.data.keys()

    assert 'Overall' in table_names
    assert 'GeneralShooting' in table_names
    assert 'ShotClockShooting' in table_names
    assert 'DribbleShooting' in table_names
    assert 'ClosestDefenderShooting' in table_names
    assert 'ClosestDefender10ftPlusShooting' in table_names
    assert 'TouchTimeShooting' in table_names

    example_overall = example_player.data['Overall'][0]
    example_gen = example_player.data['GeneralShooting'][0]
    example_clock = example_player.data['ShotClockShooting'][0]
    example_dribble = example_player.data['DribbleShooting'][0]
    example_defender = example_player.data['ClosestDefenderShooting'][0]
    example_defender10 = example_player.data['ClosestDefender10ftPlusShooting'][0]
    example_touch = example_player.data['TouchTimeShooting'][0]

    columns = ['PLAYER_ID',
               'PLAYER_NAME_LAST_FIRST',
               'SORT_ORDER',
               'GP',
               'G',
               'SHOT_TYPE',
               'FGA_FREQUENCY',
               'FGM',
               'FGA',
               'FG_PCT',
               'EFG_PCT',
               'FG2A_FREQUENCY',
               'FG2M',
               'FG2A',
               'FG2_PCT',
               'FG3A_FREQUENCY',
               'FG3M',
               'FG3A',
               'FG3_PCT']

    assert list(example_overall.keys()) == columns
    assert list(example_gen.keys()) == columns
    assert list(example_clock.keys()) == ['PLAYER_ID',
                                          'PLAYER_NAME_LAST_FIRST',
                                          'SORT_ORDER',
                                          'GP',
                                          'G',
                                          'SHOT_CLOCK_RANGE',
                                          'FGA_FREQUENCY',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'EFG_PCT',
                                          'FG2A_FREQUENCY',
                                          'FG2M',
                                          'FG2A',
                                          'FG2_PCT',
                                          'FG3A_FREQUENCY',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT']

    assert list(example_dribble.keys()) == ['PLAYER_ID',
                                           'PLAYER_NAME_LAST_FIRST',
                                           'SORT_ORDER',
                                           'GP',
                                           'G',
                                           'DRIBBLE_RANGE',
                                           'FGA_FREQUENCY',
                                           'FGM',
                                           'FGA',
                                           'FG_PCT',
                                           'EFG_PCT',
                                           'FG2A_FREQUENCY',
                                           'FG2M',
                                           'FG2A',
                                           'FG2_PCT',
                                           'FG3A_FREQUENCY',
                                           'FG3M',
                                           'FG3A',
                                           'FG3_PCT']

    assert list(example_defender.keys()) == ['PLAYER_ID',
                                             'PLAYER_NAME_LAST_FIRST',
                                             'SORT_ORDER',
                                             'GP',
                                             'G',
                                             'CLOSE_DEF_DIST_RANGE',
                                             'FGA_FREQUENCY',
                                             'FGM',
                                             'FGA',
                                             'FG_PCT',
                                             'EFG_PCT',
                                             'FG2A_FREQUENCY',
                                             'FG2M',
                                             'FG2A',
                                             'FG2_PCT',
                                             'FG3A_FREQUENCY',
                                             'FG3M',
                                             'FG3A',
                                             'FG3_PCT']

    assert list(example_defender10.keys()) == ['PLAYER_ID',
                                               'PLAYER_NAME_LAST_FIRST',
                                               'SORT_ORDER',
                                               'GP',
                                               'G',
                                               'CLOSE_DEF_DIST_RANGE',
                                               'FGA_FREQUENCY',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'EFG_PCT',
                                               'FG2A_FREQUENCY',
                                               'FG2M',
                                               'FG2A',
                                               'FG2_PCT',
                                               'FG3A_FREQUENCY',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT']

    assert list(example_touch.keys()) == ['PLAYER_ID',
                                          'PLAYER_NAME_LAST_FIRST',
                                          'SORT_ORDER',
                                          'GP',
                                          'G',
                                          'TOUCH_TIME_RANGE',
                                          'FGA_FREQUENCY',
                                          'FGM',
                                          'FGA',
                                          'FG_PCT',
                                          'EFG_PCT',
                                          'FG2A_FREQUENCY',
                                          'FG2M',
                                          'FG2A',
                                          'FG2_PCT',
                                          'FG3A_FREQUENCY',
                                          'FG3M',
                                          'FG3A',
                                          'FG3_PCT']
    
def test_player_gamelog():
    """ tests the playergamelog endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playergamelog')

    table_names = example_player.data.keys()

    assert 'PlayerGameLog' in table_names

    example_log = example_player.data['PlayerGameLog'][0]

    assert list(example_log.keys()) == ['SEASON_ID',
                                        'Player_ID',
                                        'Game_ID',
                                        'GAME_DATE',
                                        'MATCHUP',
                                        'WL',
                                        'MIN',
                                        'FGM',
                                        'FGA',
                                        'FG_PCT',
                                        'FG3M',
                                        'FG3A',
                                        'FG3_PCT',
                                        'FTM',
                                        'FTA',
                                        'FT_PCT',
                                        'OREB',
                                        'DREB',
                                        'REB',
                                        'AST',
                                        'STL',
                                        'BLK',
                                        'TOV',
                                        'PF',
                                        'PTS',
                                        'PLUS_MINUS',
                                        'VIDEO_AVAILABLE']
    
def test_playerprofile():
    """ tests the playerprofilev2 endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            player_id='203954',
                            endpoint='playerprofilev2')

    table_names = example_player.data.keys()

    assert 'SeasonTotalsRegularSeason' in table_names
    assert 'CareerTotalsRegularSeason' in table_names
    assert 'SeasonTotalsPostSeason' in table_names
    assert 'CareerTotalsPostSeason' in table_names
    assert 'SeasonTotalsAllStarSeason' in table_names
    assert 'CareerTotalsAllStarSeason' in table_names
    assert 'SeasonTotalsCollegeSeason' in table_names
    assert 'CareerTotalsCollegeSeason' in table_names
    assert 'SeasonRankingsRegularSeason' in table_names
    assert 'SeasonRankingsPostSeason' in table_names

    example_season_reg = example_player.data['SeasonTotalsRegularSeason'][0]
    example_career_reg = example_player.data['CareerTotalsRegularSeason'][0]
    example_season_post = example_player.data['SeasonTotalsPostSeason'][0]
    example_career_post = example_player.data['CareerTotalsPostSeason'][0]
    example_season_star = example_player.data['SeasonTotalsAllStarSeason'][0]
    example_career_star = example_player.data['CareerTotalsAllStarSeason'][0]
    example_season_col = example_player.data['SeasonTotalsCollegeSeason'][0]
    example_career_col = example_player.data['CareerTotalsCollegeSeason'][0]
    example_seasonrank_reg = example_player.data['SeasonRankingsRegularSeason'][0]
    example_seasonrank_post = example_player.data['SeasonRankingsPostSeason'][0]
    example_season_high = example_player.data['SeasonHighs'][0]
    example_career_high = example_player.data['CareerHighs'][0]
    example_next = example_player.data['NextGame'][0]

    columns = ['PLAYER_ID',
               'SEASON_ID',
               'LEAGUE_ID',
               'TEAM_ID',
               'TEAM_ABBREVIATION',
               'PLAYER_AGE',
               'GP',
               'GS',
               'MIN',
               'FGM',
               'FGA',
               'FG_PCT',
               'FG3M',
               'FG3A',
               'FG3_PCT',
               'FTM',
               'FTA',
               'FT_PCT',
               'OREB',
               'DREB',
               'REB',
               'AST',
               'STL',
               'BLK',
               'TOV',
               'PF',
               'PTS']

    assert list(example_season_reg.keys()) == columns

    assert list(example_career_reg.keys()) == ['PLAYER_ID',
                                               'LEAGUE_ID',
                                               'TEAM_ID',
                                               'GP',
                                               'GS',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'STL',
                                               'BLK',
                                               'TOV',
                                               'PF',
                                               'PTS']

    assert list(example_season_post.keys()) == columns

    assert list(example_career_post.keys()) == ['PLAYER_ID',
                                                'LEAGUE_ID',
                                                'TEAM_ID',
                                                'GP',
                                                'GS',
                                                'MIN',
                                                'FGM',
                                                'FGA',
                                                'FG_PCT',
                                                'FG3M',
                                                'FG3A',
                                                'FG3_PCT',
                                                'FTM',
                                                'FTA',
                                                'FT_PCT',
                                                'OREB',
                                                'DREB',
                                                'REB',
                                                'AST',
                                                'STL',
                                                'BLK',
                                                'TOV',
                                                'PF',
                                                'PTS']

    assert list(example_season_star.keys()) == columns

    assert list(example_career_star.keys()) == ['PLAYER_ID',
                                                'LEAGUE_ID',
                                                'TEAM_ID',
                                                'GP',
                                                'GS',
                                                'MIN',
                                                'FGM',
                                                'FGA',
                                                'FG_PCT',
                                                'FG3M',
                                                'FG3A',
                                                'FG3_PCT',
                                                'FTM',
                                                'FTA',
                                                'FT_PCT',
                                                'OREB',
                                                'DREB',
                                                'REB',
                                                'AST',
                                                'STL',
                                                'BLK',
                                                'TOV',
                                                'PF',
                                                'PTS']

    assert list(example_season_col.keys()) == ['PLAYER_ID',
                                               'SEASON_ID',
                                               'LEAGUE_ID',
                                               'ORGANIZATION_ID',
                                               'SCHOOL_NAME',
                                               'PLAYER_AGE',
                                               'GP',
                                               'GS',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'STL',
                                               'BLK',
                                               'TOV',
                                               'PF',
                                               'PTS']

    assert list(example_career_col.keys()) == ['PLAYER_ID',
                                               'LEAGUE_ID',
                                               'ORGANIZATION_ID',
                                               'GP',
                                               'GS',
                                               'MIN',
                                               'FGM',
                                               'FGA',
                                               'FG_PCT',
                                               'FG3M',
                                               'FG3A',
                                               'FG3_PCT',
                                               'FTM',
                                               'FTA',
                                               'FT_PCT',
                                               'OREB',
                                               'DREB',
                                               'REB',
                                               'AST',
                                               'STL',
                                               'BLK',
                                               'TOV',
                                               'PF',
                                               'PTS']

    assert list(example_seasonrank_reg.keys()) == ['PLAYER_ID',
                                                   'SEASON_ID',
                                                   'LEAGUE_ID',
                                                   'TEAM_ID',
                                                   'TEAM_ABBREVIATION',
                                                   'PLAYER_AGE',
                                                   'GP',
                                                   'GS',
                                                   'RANK_PG_MIN',
                                                   'RANK_PG_FGM',
                                                   'RANK_PG_FGA',
                                                   'RANK_FG_PCT',
                                                   'RANK_PG_FG3M',
                                                   'RANK_PG_FG3A',
                                                   'RANK_FG3_PCT',
                                                   'RANK_PG_FTM',
                                                   'RANK_PG_FTA',
                                                   'RANK_FT_PCT',
                                                   'RANK_PG_OREB',
                                                   'RANK_PG_DREB',
                                                   'RANK_PG_REB',
                                                   'RANK_PG_AST',
                                                   'RANK_PG_STL',
                                                   'RANK_PG_BLK',
                                                   'RANK_PG_TOV',
                                                   'RANK_PG_PTS',
                                                   'RANK_PG_EFF']

    assert list(example_seasonrank_post.keys()) == ['PLAYER_ID',
                                                    'SEASON_ID',
                                                    'LEAGUE_ID',
                                                    'TEAM_ID',
                                                    'TEAM_ABBREVIATION',
                                                    'PLAYER_AGE',
                                                    'GP',
                                                    'GS',
                                                    'RANK_PG_MIN',
                                                    'RANK_PG_FGM',
                                                    'RANK_PG_FGA',
                                                    'RANK_FG_PCT',
                                                    'RANK_PG_FG3M',
                                                    'RANK_PG_FG3A',
                                                    'RANK_FG3_PCT',
                                                    'RANK_PG_FTM',
                                                    'RANK_PG_FTA',
                                                    'RANK_FT_PCT',
                                                    'RANK_PG_OREB',
                                                    'RANK_PG_DREB',
                                                    'RANK_PG_REB',
                                                    'RANK_PG_AST',
                                                    'RANK_PG_STL',
                                                    'RANK_PG_BLK',
                                                    'RANK_PG_TOV',
                                                    'RANK_PG_PTS',
                                                    'RANK_PG_EFF']

    assert list(example_season_high.keys()) == ['PLAYER_ID',
                                                'GAME_ID',
                                                'GAME_DATE',
                                                'VS_TEAM_ID',
                                                'VS_TEAM_CITY',
                                                'VS_TEAM_NAME',
                                                'VS_TEAM_ABBREVIATION',
                                                'STAT',
                                                'STAT_VALUE',
                                                'STAT_ORDER',
                                                'DATE_EST']

    assert list(example_career_high.keys()) == ['PLAYER_ID',
                                                'GAME_ID',
                                                'GAME_DATE',
                                                'VS_TEAM_ID',
                                                'VS_TEAM_CITY',
                                                'VS_TEAM_NAME',
                                                'VS_TEAM_ABBREVIATION',
                                                'STAT',
                                                'STAT_VALUE',
                                                'STAT_ORDER',
                                                'DATE_EST']

    assert list(example_next.keys()) == ['GAME_ID',
                                         'GAME_DATE',
                                         'GAME_TIME',
                                         'LOCATION',
                                         'PLAYER_TEAM_ID',
                                         'PLAYER_TEAM_CITY',
                                         'PLAYER_TEAM_NICKNAME',
                                         'PLAYER_TEAM_ABBREVIATION',
                                         'VS_TEAM_ID',
                                         'VS_TEAM_CITY',
                                         'VS_TEAM_NICKNAME',
                                         'VS_TEAM_ABBREVIATION']

def test_player_v_player():
    """ tests the playervsplayer endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='playervsplayer')

    table_names = example_player.data.keys()

    assert 'Overall' in table_names
    assert 'OnOffCourt' in table_names
    assert 'ShotDistanceOverall' in table_names
    assert 'ShotDistanceOnCourt' in table_names
    assert 'ShotDistanceOffCourt' in table_names
    assert 'ShotAreaOverall' in table_names
    assert 'ShotAreaOnCourt' in table_names
    assert 'ShotAreaOffCourt' in table_names
    assert 'PlayerInfo' in table_names
    assert 'VsPlayerInfo' in table_names

    example_overall = example_player.data['Overall'][0]
    example_on_off = example_player.data['OnOffCourt'][0]
    example_dist = example_player.data['ShotDistanceOverall'][0]
    example_dist_on = example_player.data['ShotDistanceOnCourt'][0]
    example_dist_off = example_player.data['ShotDistanceOffCourt'][0]
    example_area = example_player.data['ShotAreaOverall'][0]
    example_area_on = example_player.data['ShotAreaOnCourt'][0]
    example_area_off = example_player.data['ShotAreaOffCourt'][0]
    example_player_inf = example_player.data['PlayerInfo'][0]
    example_vs_player_inf = example_player.data['VsPlayerInfo'][0]

    assert list(example_overall.keys()) == ['GROUP_SET',
                                            'GROUP_VALUE',
                                            'PLAYER_ID',
                                            'PLAYER_NAME',
                                            'GP',
                                            'W',
                                            'L',
                                            'W_PCT',
                                            'MIN',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'FG3M',
                                            'FG3A',
                                            'FG3_PCT',
                                            'FTM',
                                            'FTA',
                                            'FT_PCT',
                                            'OREB',
                                            'DREB',
                                            'REB',
                                            'AST',
                                            'TOV',
                                            'STL',
                                            'BLK',
                                            'BLKA',
                                            'PF',
                                            'PFD',
                                            'PTS',
                                            'PLUS_MINUS',
                                            'NBA_FANTASY_PTS',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_on_off.keys()) == ['GROUP_SET',
                                           'PLAYER_ID',
                                           'PLAYER_NAME',
                                           'VS_PLAYER_ID',
                                           'VS_PLAYER_NAME',
                                           'COURT_STATUS',
                                           'GP',
                                           'W',
                                           'L',
                                           'W_PCT',
                                           'MIN',
                                           'FGM',
                                           'FGA',
                                           'FG_PCT',
                                           'FG3M',
                                           'FG3A',
                                           'FG3_PCT',
                                           'FTM',
                                           'FTA',
                                           'FT_PCT',
                                           'OREB',
                                           'DREB',
                                           'REB',
                                           'AST',
                                           'TOV',
                                           'STL',
                                           'BLK',
                                           'BLKA',
                                           'PF',
                                           'PFD',
                                           'PTS',
                                           'PLUS_MINUS',
                                           'NBA_FANTASY_PTS',
                                           'CFID',
                                           'CFPARAMS']

    assert list(example_dist.keys()) == ['GROUP_SET',
                                         'GROUP_VALUE',
                                         'PLAYER_ID',
                                         'PLAYER_NAME',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'CFID',
                                         'CFPARAMS']

    assert list(example_dist_on.keys()) == ['GROUP_SET',
                                            'PLAYER_ID',
                                            'PLAYER_NAME',
                                            'VS_PLAYER_ID',
                                            'VS_PLAYER_NAME',
                                            'COURT_STATUS',
                                            'GROUP_VALUE',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'CFID',
                                            'CFPARAMS']
    assert list(example_dist_off.keys()) == ['GROUP_SET',
                                             'PLAYER_ID',
                                             'PLAYER_NAME',
                                             'VS_PLAYER_ID',
                                             'VS_PLAYER_NAME',
                                             'COURT_STATUS',
                                             'GROUP_VALUE',
                                             'FGM',
                                             'FGA',
                                             'FG_PCT',
                                             'CFID',
                                             'CFPARAMS']

    assert list(example_area.keys()) == ['GROUP_SET',
                                         'GROUP_VALUE',
                                         'PLAYER_ID',
                                         'PLAYER_NAME',
                                         'FGM',
                                         'FGA',
                                         'FG_PCT',
                                         'CFID',
                                         'CFPARAMS']

    assert list(example_area_on.keys()) == ['GROUP_SET',
                                            'PLAYER_ID',
                                            'PLAYER_NAME',
                                            'VS_PLAYER_ID',
                                            'VS_PLAYER_NAME',
                                            'COURT_STATUS',
                                            'GROUP_VALUE',
                                            'FGM',
                                            'FGA',
                                            'FG_PCT',
                                            'CFID',
                                            'CFPARAMS']

    assert list(example_area_off.keys()) == ['GROUP_SET',
                                             'PLAYER_ID',
                                             'PLAYER_NAME',
                                             'VS_PLAYER_ID',
                                             'VS_PLAYER_NAME',
                                             'COURT_STATUS',
                                             'GROUP_VALUE',
                                             'FGM',
                                             'FGA',
                                             'FG_PCT',
                                             'CFID',
                                             'CFPARAMS']

    assert list(example_player_inf.keys()) == ['PERSON_ID',
                                               'FIRST_NAME',
                                               'LAST_NAME',
                                               'DISPLAY_FIRST_LAST',
                                               'DISPLAY_LAST_COMMA_FIRST',
                                               'DISPLAY_FI_LAST',
                                               'BIRTHDATE',
                                               'SCHOOL',
                                               'COUNTRY',
                                               'LAST_AFFILIATION']

    assert list(example_vs_player_inf.keys()) == ['PERSON_ID',
                                                  'FIRST_NAME',
                                                  'LAST_NAME',
                                                  'DISPLAY_FIRST_LAST',
                                                  'DISPLAY_LAST_COMMA_FIRST',
                                                  'DISPLAY_FI_LAST',
                                                  'BIRTHDATE',
                                                  'SCHOOL',
                                                  'COUNTRY',
                                                  'LAST_AFFILIATION']

def test_player_shotchart():
    """ tests the shotchartdetail endpoint of the Player class
    """

    time.sleep(1)
    example_player = Player(headers=HEADERS,
                            endpoint='shotchartdetail',
                            game_id='0021700608',
                            player_id='2772')

    table_names = example_player.data.keys()

    assert 'Shot_Chart_Detail' in table_names
    assert 'LeagueAverages' in table_names

    example_shotchart = example_player.data['Shot_Chart_Detail'][0]
    example_avg = example_player.data['LeagueAverages'][0]

    assert list(example_shotchart.keys()) == ['GRID_TYPE',
                                              'GAME_ID',
                                              'GAME_EVENT_ID',
                                              'PLAYER_ID',
                                              'PLAYER_NAME',
                                              'TEAM_ID',
                                              'TEAM_NAME',
                                              'PERIOD',
                                              'MINUTES_REMAINING',
                                              'SECONDS_REMAINING',
                                              'EVENT_TYPE',
                                              'ACTION_TYPE',
                                              'SHOT_TYPE',
                                              'SHOT_ZONE_BASIC',
                                              'SHOT_ZONE_AREA',
                                              'SHOT_ZONE_RANGE',
                                              'SHOT_DISTANCE',
                                              'LOC_X',
                                              'LOC_Y',
                                              'SHOT_ATTEMPTED_FLAG',
                                              'SHOT_MADE_FLAG',
                                              'GAME_DATE',
                                              'HTM',
                                              'VTM']

    assert list(example_avg.keys()) == ['GRID_TYPE',
                                        'SHOT_ZONE_BASIC',
                                        'SHOT_ZONE_AREA',
                                        'SHOT_ZONE_RANGE',
                                        'FGA',
                                        'FGM',
                                        'FG_PCT']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Dec 23 21:54:48 2018

@author: patrickmcfarlane

test_scoreboard.py

This function contains the tests for
functions in the scoreboard.py file
"""

import time

from .__init__ import HEADERS
from ..scoreboard import ScoreBoard

def test_scoreboard():
    """ tests the scoreboard endpoint of the ScoreBoard class
    """

    time.sleep(1)
    example_board = ScoreBoard(headers=HEADERS,
                               game_date='12/22/2018')

    table_names = example_board.data.keys()

    assert 'GameHeader' in table_names
    assert 'LineScore' in table_names
    assert 'SeriesStandings' in table_names
    assert 'LastMeeting' in table_names
    assert 'EastConfStandingsByDay' in table_names
    assert 'WestConfStandingsByDay' in table_names
    assert 'Available' in table_names

    example_game = example_board.data['GameHeader'][0]
    example_line = example_board.data['LineScore'][0]
    example_series = example_board.data['SeriesStandings'][0]
    example_last = example_board.data['LastMeeting'][0]
    example_east = example_board.data['EastConfStandingsByDay'][0]
    example_west = example_board.data['WestConfStandingsByDay'][0]
    example_avail = example_board.data['Available'][0]

    assert list(example_game.keys()) == ['GAME_DATE_EST',
                                         'GAME_SEQUENCE',
                                         'GAME_ID',
                                         'GAME_STATUS_ID',
                                         'GAME_STATUS_TEXT',
                                         'GAMECODE',
                                         'HOME_TEAM_ID',
                                         'VISITOR_TEAM_ID',
                                         'SEASON',
                                         'LIVE_PERIOD',
                                         'LIVE_PC_TIME',
                                         'NATL_TV_BROADCASTER_ABBREVIATION',
                                         'LIVE_PERIOD_TIME_BCAST',
                                         'WH_STATUS']

    assert list(example_line.keys()) == ['GAME_DATE_EST',
                                         'GAME_SEQUENCE',
                                         'GAME_ID',
                                         'TEAM_ID',
                                         'TEAM_ABBREVIATION',
                                         'TEAM_CITY_NAME',
                                         'TEAM_WINS_LOSSES',
                                         'PTS_QTR1',
                                         'PTS_QTR2',
                                         'PTS_QTR3',
                                         'PTS_QTR4',
                                         'PTS_OT1',
                                         'PTS_OT2',
                                         'PTS_OT3',
                                         'PTS_OT4',
                                         'PTS_OT5',
                                         'PTS_OT6',
                                         'PTS_OT7',
                                         'PTS_OT8',
                                         'PTS_OT9',
                                         'PTS_OT10',
                                         'PTS',
                                         'FG_PCT',
                                         'FT_PCT',
                                         'FG3_PCT',
                                         'AST',
                                         'REB',
                                         'TOV']

    assert list(example_series.keys()) == ['GAME_ID',
                                           'HOME_TEAM_ID',
                                           'VISITOR_TEAM_ID',
                                           'GAME_DATE_EST',
                                           'HOME_TEAM_WINS',
                                           'HOME_TEAM_LOSSES',
                                           'SERIES_LEADER']

    assert list(example_last.keys()) == ['GAME_ID',
                                         'LAST_GAME_ID',
                                         'LAST_GAME_DATE_EST',
                                         'LAST_GAME_HOME_TEAM_ID',
                                         'LAST_GAME_HOME_TEAM_CITY',
                                         'LAST_GAME_HOME_TEAM_NAME',
                                         'LAST_GAME_HOME_TEAM_ABBREVIATION',
                                         'LAST_GAME_HOME_TEAM_POINTS',
                                         'LAST_GAME_VISITOR_TEAM_ID',
                                         'LAST_GAME_VISITOR_TEAM_CITY',
                                         'LAST_GAME_VISITOR_TEAM_NAME',
                                         'LAST_GAME_VISITOR_TEAM_CITY1',
                                         'LAST_GAME_VISITOR_TEAM_POINTS']

    assert list(example_east.keys()) == ['TEAM_ID',
                                         'LEAGUE_ID',
                                         'SEASON_ID',
                                         'STANDINGSDATE',
                                         'CONFERENCE',
                                         'TEAM',
                                         'G',
                                         'W',
                                         'L',
                                         'W_PCT',
                                         'HOME_RECORD',
                                         'ROAD_RECORD']

    assert list(example_west.keys()) == ['TEAM_ID',
                                         'LEAGUE_ID',
                                         'SEASON_ID',
                                         'STANDINGSDATE',
                                         'CONFERENCE',
                                         'TEAM',
                                         'G',
                                         'W',
                                         'L',
                                         'W_PCT',
                                         'HOME_RECORD',
                                         'ROAD_RECORD']

    assert list(example_avail.keys()) == ['GAME_ID', 'PT_AVAILABLE']

def test_scoreboardv2():
    """ tests the scoreboardv2 endpoint of the ScoreBoard class
    """

    time.sleep(1)
    example_board = ScoreBoard(headers=HEADERS,
                               endpoint='scoreboardv2',
                               game_date='12/22/2018')

    table_names = example_board.data.keys()

    assert 'GameHeader' in table_names
    assert 'LineScore' in table_names
    assert 'SeriesStandings' in table_names
    assert 'LastMeeting' in table_names
    assert 'EastConfStandingsByDay' in table_names
    assert 'WestConfStandingsByDay' in table_names
    assert 'Available' in table_names
    assert 'TeamLeaders' in table_names
    assert 'TicketLinks' in table_names
    assert 'WinProbability' in table_names

    example_game = example_board.data['GameHeader'][0]
    example_line = example_board.data['LineScore'][0]
    example_series = example_board.data['SeriesStandings'][0]
    example_last = example_board.data['LastMeeting'][0]
    example_east = example_board.data['EastConfStandingsByDay'][0]
    example_west = example_board.data['WestConfStandingsByDay'][0]
    example_avail = example_board.data['Available'][0]
    example_lead = example_board.data['TeamLeaders'][0]
    example_tick = example_board.data['TicketLinks'][0]

    assert list(example_game.keys()) == ['GAME_DATE_EST',
                                         'GAME_SEQUENCE',
                                         'GAME_ID',
                                         'GAME_STATUS_ID',
                                         'GAME_STATUS_TEXT',
                                         'GAMECODE',
                                         'HOME_TEAM_ID',
                                         'VISITOR_TEAM_ID',
                                         'SEASON',
                                         'LIVE_PERIOD',
                                         'LIVE_PC_TIME',
                                         'NATL_TV_BROADCASTER_ABBREVIATION',
                                         'HOME_TV_BROADCASTER_ABBREVIATION',
                                         'AWAY_TV_BROADCASTER_ABBREVIATION',
                                         'LIVE_PERIOD_TIME_BCAST',
                                         'ARENA_NAME',
                                         'WH_STATUS']

    assert list(example_line.keys()) == ['GAME_DATE_EST',
                                         'GAME_SEQUENCE',
                                         'GAME_ID',
                                         'TEAM_ID',
                                         'TEAM_ABBREVIATION',
                                         'TEAM_CITY_NAME',
                                         'TEAM_NAME',
                                         'TEAM_WINS_LOSSES',
                                         'PTS_QTR1',
                                         'PTS_QTR2',
                                         'PTS_QTR3',
                                         'PTS_QTR4',
                                         'PTS_OT1',
                                         'PTS_OT2',
                                         'PTS_OT3',
                                         'PTS_OT4',
                                         'PTS_OT5',
                                         'PTS_OT6',
                                         'PTS_OT7',
                                         'PTS_OT8',
                                         'PTS_OT9',
                                         'PTS_OT10',
                                         'PTS',
                                         'FG_PCT',
                                         'FT_PCT',
                                         'FG3_PCT',
                                         'AST',
                                         'REB',
                                         'TOV']

    assert list(example_series.keys()) == ['GAME_ID',
                                           'HOME_TEAM_ID',
                                           'VISITOR_TEAM_ID',
                                           'GAME_DATE_EST',
                                           'HOME_TEAM_WINS',
                                           'HOME_TEAM_LOSSES',
                                           'SERIES_LEADER']

    assert list(example_last.keys()) == ['GAME_ID',
                                         'LAST_GAME_ID',
                                         'LAST_GAME_DATE_EST',
                                         'LAST_GAME_HOME_TEAM_ID',
                                         'LAST_GAME_HOME_TEAM_CITY',
                                         'LAST_GAME_HOME_TEAM_NAME',
                                         'LAST_GAME_HOME_TEAM_ABBREVIATION',
                                         'LAST_GAME_HOME_TEAM_POINTS',
                                         'LAST_GAME_VISITOR_TEAM_ID',
                                         'LAST_GAME_VISITOR_TEAM_CITY',
                                         'LAST_GAME_VISITOR_TEAM_NAME',
                                         'LAST_GAME_VISITOR_TEAM_CITY1',
                                         'LAST_GAME_VISITOR_TEAM_POINTS']

    assert list(example_east.keys()) == ['TEAM_ID',
                                         'LEAGUE_ID',
                                         'SEASON_ID',
                                         'STANDINGSDATE',
                                         'CONFERENCE',
                                         'TEAM',
                                         'G',
                                         'W',
                                         'L',
                                         'W_PCT',
                                         'HOME_RECORD',
                                         'ROAD_RECORD']

    assert list(example_west.keys()) == ['TEAM_ID',
                                         'LEAGUE_ID',
                                         'SEASON_ID',
                                         'STANDINGSDATE',
                                         'CONFERENCE',
                                         'TEAM',
                                         'G',
                                         'W',
                                         'L',
                                         'W_PCT',
                                         'HOME_RECORD',
                                         'ROAD_RECORD']

    assert list(example_avail.keys()) == ['GAME_ID', 'PT_AVAILABLE']

    assert list(example_lead.keys()) == ['GAME_ID',
                                         'TEAM_ID',
                                         'TEAM_CITY',
                                         'TEAM_NICKNAME',
                                         'TEAM_ABBREVIATION',
                                         'PTS_PLAYER_ID',
                                         'PTS_PLAYER_NAME',
                                         'PTS',
                                         'REB_PLAYER_ID',
                                         'REB_PLAYER_NAME',
                                         'REB',
                                         'AST_PLAYER_ID',
                                         'AST_PLAYER_NAME',
                                         'AST']

    assert list(example_tick.keys()) == ['GAME_ID', 'LEAG_TIX']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 22 14:37:05 2018

@author: patrickmcfarlane

test_league.py

This function contains the tests for
functions in the league.py file
"""

from .__init__ import HEADERS
from ..league import League

def test_all_players():
    """ tests the commonallplayers endpoint of the League class
    """

    example_league = League(headers=HEADERS)

    table_names = example_league.data.keys()

    assert 'CommonAllPlayers' in table_names

    example_players = example_league.data['CommonAllPlayers'][0]

    assert list(example_players.keys()) == ['PERSON_ID',
                                            'DISPLAY_LAST_COMMA_FIRST',
                                            'DISPLAY_FIRST_LAST',
                                            'ROSTERSTATUS',
                                            'FROM_YEAR',
                                            'TO_YEAR',
                                            'PLAYERCODE',
                                            'TEAM_ID',
                                            'TEAM_CITY',
                                            'TEAM_NAME',
                                            'TEAM_ABBREVIATION',
                                            'TEAM_CODE',
                                            'GAMES_PLAYED_FLAG']

def test_team_years():
    """ tests the commonteamyears endpoint of the League class
    """

    example_league = League(headers=HEADERS, endpoint='commonteamyears')

    table_names = example_league.data.keys()

    assert 'TeamYears' in table_names

    example_teams = example_league.data['TeamYears'][0]

    assert list(example_teams.keys()) == ['LEAGUE_ID',
                                          'TEAM_ID',
                                          'MIN_YEAR',
                                          'MAX_YEAR',
                                          'ABBREVIATION']

def test_playoff_series():
    """ tests the commonplayoffseries endpoint of the League class
    """

    example_league = League(headers=HEADERS, endpoint='commonplayoffseries')

    table_names = example_league.data.keys()

    assert 'PlayoffSeries' in table_names

    example_playoffs = example_league.data['PlayoffSeries'][0]

    assert list(example_playoffs.keys()) == ['GAME_ID',
                                             'HOME_TEAM_ID',
                                             'VISITOR_TEAM_ID',
                                             'SERIES_ID',
                                             'GAME_NUM']
def test_franchise_history():
    """ tests the franchisehistory endpoint of the League class
    """

    example_league = League(headers=HEADERS, endpoint='franchisehistory')

    table_names = example_league.data.keys()

    assert 'FranchiseHistory' in table_names
    assert 'DefunctTeams' in table_names

    example_franchise = example_league.data['FranchiseHistory'][0]
    example_defunct = example_league.data['DefunctTeams'][0]

    assert list(example_franchise.keys()) == ['LEAGUE_ID',
                                              'TEAM_ID',
                                              'TEAM_CITY',
                                              'TEAM_NAME',
                                              'START_YEAR',
                                              'END_YEAR',
                                              'YEARS',
                                              'GAMES',
                                              'WINS',
                                              'LOSSES',
                                              'WIN_PCT',
                                              'PO_APPEARANCES',
                                              'DIV_TITLES',
                                              'CONF_TITLES',
                                              'LEAGUE_TITLES']

    assert list(example_defunct.keys()) == ['LEAGUE_ID',
                                            'TEAM_ID',
                                            'TEAM_CITY',
                                            'TEAM_NAME',
                                            'START_YEAR',
                                            'END_YEAR',
                                            'YEARS',
                                            'GAMES',
                                            'WINS',
                                            'LOSSES',
                                            'WIN_PCT',
                                            'PO_APPEARANCES',
                                            'DIV_TITLES',
                                            'CONF_TITLES',
                                            'LEAGUE_TITLES']

def test_playoff_picture():
    """ tests the playoffpicture endpoint of the League class
    """

    example_league = League(headers=HEADERS, endpoint='playoffpicture')

    table_names = example_league.data.keys()

    assert 'EastConfPlayoffPicture' in table_names
    assert 'WestConfPlayoffPicture' in table_names
    assert 'EastConfStandings' in table_names
    assert 'WestConfStandings' in table_names
    assert 'EastConfRemainingGames' in table_names
    assert 'WestConfRemainingGames' in table_names

    example_east_pp = example_league.data['EastConfPlayoffPicture'][0]
    example_west_pp = example_league.data['WestConfPlayoffPicture'][0]
    example_east_stand = example_league.data['EastConfStandings'][0]
    example_west_stand = example_league.data['WestConfStandings'][0]
    example_east_rem = example_league.data['EastConfRemainingGames'][0]
    example_west_rem = example_league.data['WestConfRemainingGames'][0]

    assert list(example_east_pp.keys()) == ['CONFERENCE',
                                            'HIGH_SEED_RANK',
                                            'HIGH_SEED_TEAM',
                                            'HIGH_SEED_TEAM_ID',
                                            'LOW_SEED_RANK',
                                            'LOW_SEED_TEAM',
                                            'LOW_SEED_TEAM_ID',
                                            'HIGH_SEED_SERIES_W',
                                            'HIGH_SEED_SERIES_L',
                                            'HIGH_SEED_SERIES_REMAINING_G',
                                            'HIGH_SEED_SERIES_REMAINING_HOME_G',
                                            'HIGH_SEED_SERIES_REMAINING_AWAY_G']

    assert list(example_west_pp.keys()) == ['CONFERENCE',
                                            'HIGH_SEED_RANK',
                                            'HIGH_SEED_TEAM',
                                            'HIGH_SEED_TEAM_ID',
                                            'LOW_SEED_RANK',
                                            'LOW_SEED_TEAM',
                                            'LOW_SEED_TEAM_ID',
                                            'HIGH_SEED_SERIES_W',
                                            'HIGH_SEED_SERIES_L',
                                            'HIGH_SEED_SERIES_REMAINING_G',
                                            'HIGH_SEED_SERIES_REMAINING_HOME_G',
                                            'HIGH_SEED_SERIES_REMAINING_AWAY_G']

    assert list(example_east_stand.keys()) == ['CONFERENCE',
                                               'RANK',
                                               'TEAM',
                                               'TEAM_ID',
                                               'WINS',
                                               'LOSSES',
                                               'PCT',
                                               'DIV',
                                               'CONF',
                                               'HOME',
                                               'AWAY',
                                               'GB',
                                               'GR_OVER_500',
                                               'GR_OVER_500_HOME',
                                               'GR_OVER_500_AWAY',
                                               'GR_UNDER_500',
                                               'GR_UNDER_500_HOME',
                                               'GR_UNDER_500_AWAY',
                                               'RANKING_CRITERIA',
                                               'CLINCHED_PLAYOFFS',
                                               'CLINCHED_CONFERENCE',
                                               'CLINCHED_DIVISION',
                                               'ELIMINATED_PLAYOFFS',
                                               'SOSA_REMAINING']

    assert list(example_west_stand.keys()) == ['CONFERENCE',
                                               'RANK',
                                               'TEAM',
                                               'TEAM_ID',
                                               'WINS',
                                               'LOSSES',
                                               'PCT',
                                               'DIV',
                                               'CONF',
                                               'HOME',
                                               'AWAY',
                                               'GB',
                                               'GR_OVER_500',
                                               'GR_OVER_500_HOME',
                                               'GR_OVER_500_AWAY',
                                               'GR_UNDER_500',
                                               'GR_UNDER_500_HOME',
                                               'GR_UNDER_500_AWAY',
                                               'RANKING_CRITERIA',
                                               'CLINCHED_PLAYOFFS',
                                               'CLINCHED_CONFERENCE',
                                               'CLINCHED_DIVISION',
                                               'ELIMINATED_PLAYOFFS',
                                               'SOSA_REMAINING']

    assert list(example_east_rem.keys()) == ['TEAM',
                                             'TEAM_ID',
                                             'REMAINING_G',
                                             'REMAINING_HOME_G',
                                             'REMAINING_AWAY_G']

    assert list(example_west_rem.keys()) == ['TEAM',
                                             'TEAM_ID',
                                             'REMAINING_G',
                                             'REMAINING_HOME_G',
                                             'REMAINING_AWAY_G']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Jul 20 16:04:03 2019

@author: patrickmcfarlane

vegas.py contains the Vegas class that
enables SDQL queries of `sportsdatabase.com <https://sportsdatabase.com>`_
"""

from requests import get

SDQL_URL = "https://sportsdatabase.com/{league}/" + \
    "query?output=default&sdql=date%3D{date}+and+site%3Dhome&submit=++S+D+Q+L+%21++"


def parse_sdql(html_text):
    """ parse_sdql extracts the data tables from the HTML
    text provided

    @param html_text (str): String of the site HTML containing
        the data table

    Returns:

        data_dict (dict): Dictionary containing SDQL data. Returns an empty
            dictionary 
    """


    start_val = html_text.find('--Start Games Row--')
    if start_val != -1:
        html_text = html_text[start_val + 19:]

        # Get column names and initialize data_dict
        column_headers = []
        data_dict = {}
        for _ in range(20):
            start_ind = html_text.find('<th>')
            end_ind = html_text.find('</th>')
            val = html_text[start_ind + 4: end_ind]
            column_headers.append(val)
            data_dict[val] = []
            html_text = html_text[end_ind + 5: ]

        # Fill in the dictionary with each row of data
        end_val = html_text.find('--End Games Row--')
        count = 0
        while end_val > 100:
            for columns in column_headers:
                start_ind = html_text.find('\n<td valign=top')
                end_ind = html_text.find('\n</td>')
                val = html_text[start_ind + 32: end_ind]
                if '<b>' in val:
                    val = val.replace('<b>', '')
                    val = val.replace('</b>', '')
                data_dict[columns] = data_dict[columns] + [val]
                html_text = html_text[end_ind + 6: ]
                end_val = html_text.find('--End Games Row--')
            count += 1
            if count > 20:
                break

    else:
        data_dict = {}
        
    return data_dict


class Vegas:
    """ The Vegas class contains all resources needed to use query 
    `sportsdatabase.com <https://sportsdatabase.com>`_.

    The Vegas class has the following required parameters:

        @param **date** (*str*): String of a date in YYYYMMDD format.

        @param **league** (*str*): One of 'nba' or 'wnba' corresponding to
            the league of interest

    Attributes:

        **api_resp** (*dict*): Text of the HTML response from the site.

        **data** (*dict*): A dictionary of data on the provided date
            keyed by column names.
    """

    def __init__(self, headers, date, league):

        url = SDQL_URL.format(league=league,
                              date=date)

        api_response = get(url, headers=headers)
        self.api_resp = api_response.text
        # Storing the API response in a dictionary called data
        # The results can come in different formats, namely a
        # dictionary keyed by either resultSets or resultSet
        self.data = parse_sdql(self.api_resp)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Jun  9 11:02:05 2019

@author: patrickmcfarlane

salaries.py contains the functions
to gather NBA salary information
"""

from requests import get

SALARY_URL = "https://hoopshype.com/salaries/"

URL_TO_ID_NBA = {'https://hoopshype.com/salaries/toronto_raptors/': '1610612761',
                 'https://hoopshype.com/salaries/denver_nuggets/': '1610612743',
                 'https://hoopshype.com/salaries/detroit_pistons/': '1610612765',
                 'https://hoopshype.com/salaries/new_orleans_pelicans/': '1610612740',
                 'https://hoopshype.com/salaries/milwaukee_bucks/': '1610612749',
                 'https://hoopshype.com/salaries/golden_state_warriors/': '1610612744',
                 'https://hoopshype.com/salaries/san_antonio_spurs/': '1610612759',
                 'https://hoopshype.com/salaries/portland_trail_blazers/': '1610612757',
                 'https://hoopshype.com/salaries/los_angeles_clippers/': '1610612746',
                 'https://hoopshype.com/salaries/dallas_mavericks/': '1610612742',
                 'https://hoopshype.com/salaries/memphis_grizzlies/': '1610612763',
                 'https://hoopshype.com/salaries/philadelphia_76ers/': '1610612755',
                 'https://hoopshype.com/salaries/boston_celtics/': '1610612738',
                 'https://hoopshype.com/salaries/minnesota_timberwolves/': '1610612750',
                 'https://hoopshype.com/salaries/charlotte_hornets/': '1610612766',
                 'https://hoopshype.com/salaries/indiana_pacers/': '1610612754',
                 'https://hoopshype.com/salaries/orlando_magic/': '1610612753',
                 'https://hoopshype.com/salaries/miami_heat/': '1610612748',
                 'https://hoopshype.com/salaries/houston_rockets/': '1610612745',
                 'https://hoopshype.com/salaries/sacramento_kings/': '1610612758',
                 'https://hoopshype.com/salaries/utah_jazz/': '1610612762',
                 'https://hoopshype.com/salaries/brooklyn_nets/': '1610612751',
                 'https://hoopshype.com/salaries/atlanta_hawks/': '1610612737',
                 'https://hoopshype.com/salaries/phoenix_suns/': '1610612756',
                 'https://hoopshype.com/salaries/washington_wizards/': '1610612764',
                 'https://hoopshype.com/salaries/new_york_knicks/': '1610612752',
                 'https://hoopshype.com/salaries/oklahoma_city_thunder/': '1610612760',
                 'https://hoopshype.com/salaries/los_angeles_lakers/': '1610612747',
                 'https://hoopshype.com/salaries/cleveland_cavaliers/': '1610612739',
                 'https://hoopshype.com/salaries/chicago_bulls/': '1610612741'}


def salary_columns(html_text, context='current'):
    """ salary_columns returns the column names
    for the salary information

    @param **html_text** (*str*): String of the HTML response
    from SALARY_URL

    @param **context** (*str*): 'current' signifies that current
        and future salaries are being pulled. Otherwise, historical
        values are returned

    Returns:

        **html_text** (*str*): Truncated string of the HTML
            response from a Hoopshype URL with the column information
            removed

        **column_list** (*list*): List of column names for
            salary information
    """
    if context == 'current':
        col_count = 6
    else:
        col_count = 2

    column_list = []
    for col_count in range(0, col_count):
        start_ind = html_text.find('>') + 1
        end_ind = html_text.find('</td>')
        column_list.append(html_text[start_ind:end_ind])
        html_text = html_text[end_ind + 5:]

    return html_text, column_list


def get_option(option):
    """ get_option returns the type of option (if any) applied
    to that year's salary

    @param **option** (*str*): Sting of color indicators that
        correspond to yearly options.

    Returns:
        
        **option** (*list*): One of '', 'Team',
        'Qualifying', 'Two-Way', 'Player'
    """

    if option == 'color:black':
        option = ''
    elif option == 'color:rgb(255, 0, 0)':
        option = 'Team'
    elif option == 'color:rgb(0, 153, 0)':
        option = 'Qualifying'
    elif option == 'color:rgb(168, 0, 212)':
        option = 'Two-Way'
    elif option == 'color:rgb(4, 134, 176)':
        option = 'Player'
    else:
        option = ''

    return option


def team_salary_values(html_text):
    """ team_salary_values returns a dictionary of
    salary information keyed by NBA team ID

    @param **html_text** (*str*): String of the HTML response
    from SALARY_URL

    Returns:

        **team_salaries** (*dict*): Dictionary keyed by NBA
            team ID with a list of yearly salaries (followed
            by team salary URL) as values
    """
    value_str = 'data-value="'
    team_salaries = {}
    nba_teams = 30

    for teams in range(0, nba_teams):
        team_list = []
        start_ind = html_text.find('<a')
        end_ind = html_text.find('</a>')
        team_key = html_text[start_ind + 2: end_ind]
        team_key = team_key[team_key.find('href="') + 6:team_key.find('">\n')]
        html_text = html_text[end_ind + 4:]
        for col_count in range(0, 6):
            start_ind = html_text.find(value_str) + len(value_str)
            end_ind = html_text.find('">')
            team_list.append(int(html_text[start_ind:end_ind]))
            html_text = html_text[end_ind + 2:]
        team_list.append(team_key)
        team_salaries[URL_TO_ID_NBA[team_key]] = team_list

    return team_salaries


def team_player_salary_values(html_text):
    """ team_player_salary_values returns a dictionary of
    salary information keyed by Hoopshype player ID

    @param **html_text** (*str*): String of the HTML response
    from a Hoopshype team URL

    Returns:

        **player_salaries** (*dict*): Dictionary keyed by Hoopshype
            player ID with a list of yearly salaries (followed
            by player salary URL) as values
    """
    value_str = 'data-value="'
    option_str = 'style="'
    player_salaries = {}
    url_val = html_text.find('<a')
    total_val = html_text.find('class="name">Totals</td>')

    while url_val < total_val:
        player_list = []
        option_list = []
        start_ind = html_text.find('<a')
        end_ind = html_text.find('</a>')
        play_key = html_text[start_ind + 2: end_ind]
        play_key = play_key[play_key.find('href="') + 6:play_key.find('">\n')]
        player_key = play_key.split('/')[-3]
        html_text = html_text[end_ind + 4:]
        for col_count in range(0, 2):
            start_ind = html_text.find(option_str) + len(option_str)
            end_ind = html_text.find('" ')
            option = get_option(html_text[start_ind:end_ind])
            option_list.append(option)
            html_text = html_text[end_ind + 2:]

            start_ind = html_text.find(value_str) + len(value_str)
            end_ind = html_text.find('">')
            try:
                salary_value = int(html_text[start_ind:end_ind])
            except:
                salary_value = 0
            player_list.append(salary_value)
            html_text = html_text[end_ind + 2:]

        player_list.append(play_key)
        player_salaries[player_key] = {}
        player_salaries[player_key]['salary'] = player_list
        player_salaries[player_key]['options'] = option_list

        total_val = html_text.find('class="name">Totals</td>')
        url_val = html_text.find('<a')

    return player_salaries


def historical_team_salary_values(html_text, season):
    """ historical_team_salary_values returns a dictionary of
    salary information keyed by NBA team ID

    @param **html_text** (*str*): String of the HTML response
    from SALARY_URL + season
    @param **season** (*str*): String of season in YYYY-ZZZZ
    format

    Returns:

        **team_salaries** (*dict*): Dictionary keyed by NBA
            team ID with a list of yearly salaries (followed
            by team salary URL) as values
    """
    value_str = 'data-value="'
    team_salaries = {}
    nba_teams = 30

    for teams in range(0, nba_teams):
        team_list = []
        start_ind = html_text.find('<a')
        end_ind = html_text.find('</a>')
        team_key = html_text[start_ind + 2: end_ind]
        team_key = team_key[team_key.find('href="') + 6:team_key.find('">\n')]
        html_text = html_text[end_ind + 4:]
        for col_count in range(0, 2):
            start_ind = html_text.find(value_str) + len(value_str)
            end_ind = html_text.find('">')
            team_list.append(int(html_text[start_ind:end_ind]))
            html_text = html_text[end_ind + 2:]
        team_list.append(team_key)
        team_key = team_key.replace(season + '/', '')
        team_salaries[URL_TO_ID_NBA[team_key]] = team_list

    return team_salaries


def get_team_salary():
    """ This function pulls team salary information for six seasons
    from `hoopshype.com <https://hoopshype.com/salaries/>`

    Returns:

        **team_salaries** (*dict*): Dictionary keyed by NBA
            team ID with a list of yearly salaries (followed
            by team salary URL) as values

        **column_list** (*list*): List of column names for team
            salary information
    """

    api_resp = get(SALARY_URL)
    html_text = api_resp.text
    sorted_str = 'hh-salaries-sorted'

    table_index = html_text.find(sorted_str)
    html_text = html_text[table_index:]
    html_text, column_list = salary_columns(html_text, 'current')
    column_list.append('url')

    team_salaries = team_salary_values(html_text)

    return team_salaries, column_list


def get_historical_team_salary(season):
    """ This function pulls historical team salary
    information for the given season 
    from `hoopshype.com <https://hoopshype.com/salaries/>`

    @param **season** (*str*): Season in YYYY-ZZZZ format. For example,
        '2017-2018' corresponds to the 2017-2018 NBA season

    Returns:

        **team_salaries** (*dict*): Dictionary keyed by NBA
            team ID with yearly salaries and inflation-adjusted
            yearly salaries (followed by team salary URL) as values

        **column_list** (*list*): List of column names for historical team
            salary information
    """

    api_resp = get(SALARY_URL + season)
    html_text = api_resp.text
    sorted_str = 'class="name">Team</td>'

    table_index = html_text.find(sorted_str) + len(sorted_str)
    html_text = html_text[table_index:]
    html_text, column_list = salary_columns(html_text, 'historical')
    column_list.append('url')

    team_salaries = historical_team_salary_values(html_text, season)

    return team_salaries, column_list
    

def player_salary_values(html_text):
    """ player_salary_values returns a dictionary of
    salary information keyed by Hoopshype player ID

    @param **html_text** (*str*): String of the HTML response
    from a Hoopshype team URL

    Returns:

        **player_salaries** (*dict*): Dictionary keyed by Hoopshype
            player ID with a list of yearly salaries (followed
            by player salary URL) as values
    """
    value_str = 'data-value="'
    option_str = 'style="'
    player_salaries = {}
    url_val = html_text.find('<a')
    total_val = html_text.find('class="name">Totals</td>')

    while url_val < total_val:
        player_list = []
        option_list = []
        start_ind = html_text.find('<a')
        end_ind = html_text.find('</a>')
        play_key = html_text[start_ind + 2: end_ind]
        play_key = play_key[play_key.find('href="') + 6:play_key.find('">\n')]
        player_key = play_key.split('/')[-3]
        html_text = html_text[end_ind + 4:]
        for col_count in range(0, 6):
            start_ind = html_text.find(option_str) + len(option_str)
            end_ind = html_text.find('" ')
            option = get_option(html_text[start_ind:end_ind])
            option_list.append(option)
            html_text = html_text[end_ind + 2:]

            start_ind = html_text.find(value_str) + len(value_str)
            end_ind = html_text.find('">')
            try:
                salary_value = int(html_text[start_ind:end_ind])
            except:
                salary_value = 0
            player_list.append(salary_value)
            html_text = html_text[end_ind + 2:]

        player_list.append(play_key)
        player_salaries[player_key] = {}
        player_salaries[player_key]['salary'] = player_list
        player_salaries[player_key]['options'] = option_list

        total_val = html_text.find('class="name">Totals</td>')
        url_val = html_text.find('<a')

    return player_salaries


def historical_player_salary_values(html_text):
    """ historical_player_salary_values returns a dictionary of
    salary information keyed by Hoopshype player ID

    @param **html_text** (*str*): String of the HTML response
    from a Hoopshype team URL

    Returns:

        **player_salaries** (*dict*): Dictionary keyed by Hoopshype
            player ID with a list of salary and inflation-adjusted
            salary (followed by player salary URL) as values
    """
    value_str = 'data-value="'
    option_str = 'style="'
    player_salaries = {}
    url_val = html_text.find('<a')
    total_val = html_text.find('class="name">Totals</td>')

    while url_val < total_val:
        player_list = []
        start_ind = html_text.find('<a')
        end_ind = html_text.find('</a>')
        play_key = html_text[start_ind + 2: end_ind]
        play_key = play_key[play_key.find('href="') + 6:play_key.find('">\n')]
        player_key = play_key.split('/')[-3]
        html_text = html_text[end_ind + 4:]
        for col_count in range(0, 2):
            start_ind = html_text.find(option_str) + len(option_str)
            end_ind = html_text.find('" ')
            html_text = html_text[end_ind + 2:]

            start_ind = html_text.find(value_str) + len(value_str)
            end_ind = html_text.find('">')
            try:
                salary_value = int(html_text[start_ind:end_ind])
            except:
                salary_value = 0
            player_list.append(salary_value)
            html_text = html_text[end_ind + 2:]

        player_list.append(play_key)
        player_salaries[player_key] = {}
        player_salaries[player_key]['salary'] = player_list

        total_val = html_text.find('class="name">Totals</td>')
        url_val = html_text.find('<a')

    return player_salaries


def get_player_salary(team_url):
    """ This function pulls player salary information for six seasons
    from `hoopshype.com <https://hoopshype.com/salaries/>`

    @param team_url (str): String of URL corresponding
    to a single team's salary

    Returns:

        **player_salaries** (*dict*): Dictionary keyed by Hoopshype
            player ID with a list of yearly salaries as values

        **column_list** (*list*): List of column names for team
            salary information
    """

    api_resp = get(team_url)
    html_text = api_resp.text
    sorted_str = 'hh-salaries-sorted'
    
    table_index = html_text.find(sorted_str)
    html_text = html_text[table_index:]
    html_text, column_list = salary_columns(html_text)
    column_list.append('url')

    player_salaries = player_salary_values(html_text)

    return player_salaries, column_list


def get_historical_player_salary(team_url, season):
    """ This function pulls historical player salary information for six seasons
    from `hoopshype.com <https://hoopshype.com/salaries/>`

    @param **team_url** (*str*): Hoopshype URL beginning with SALARY_URL
        appended with a season value. For example,
        'https://hoopshype.com/salaries/dallas_mavericks/2017-2018/' is a valid
        **team_url**

    @param **season** (*str*): Season in YYYY-ZZZZ format. For example,
        '2017-2018' corresponds to the 2017-2018 NBA season
    Returns:

        **player_salaries** (*dict*): Dictionary keyed by Hoopshype
            player ID with a list of yearly salaries as values

        **column_list** (*list*): List of column names for team
            salary information
    """

    api_resp = get(team_url)
    html_text = api_resp.text
    sorted_str = 'class="name">Player</td>'
    
    table_index = html_text.find(sorted_str) + len(sorted_str)
    html_text = html_text[table_index:]
    html_text, column_list = salary_columns(html_text, season)
    column_list.append('url')

    player_salaries = historical_player_salary_values(html_text)

    return player_salaries, column_list
      

class TeamSalaries:
    """ The TeamSalaries class contains all resources needed
    to scrape team salary information from
    `hoopshype.com <https://hoopshype.com/salaries/>`.
    This class contains both team total salary as well as individual
    player breakdowns

    Attributes:

        **totals** (*dict*): Dictionary keyed by NBA
            team ID with a list of yearly salaries (followed
            by team salary URL) as values

        **totals_columns** (*list*): List of column names for team
            salary information

        **team_player_salaries** (*dict*): Dictionary keyed by both NBA
            team ID and Hoopshype player ID with values containing both
            salary and option information

        **team_player_columns** (*list*): List of column names for team-player
            salary information
    """

    def __init__(self):

        # First, total team salary information is pulled
        team_salaries, column_list = get_team_salary()
        self.totals = team_salaries
        self.totals_columns = column_list
        team_player_salary = {}
        for team_id in team_salaries:
            team_url = team_salaries[team_id][-1]
            player_salaries, column_list = get_player_salary(team_url)
            team_player_salary[team_id] = player_salaries

        self.team_player_salaries = team_player_salary
        self.team_player_columns = column_list


class HistoricalSalaries:
    """ The HistoricalSalaries class contains all resources needed
    to scrape team salary information from
    `hoopshype.com <https://hoopshype.com/salaries/>` for a given season.
    This class contains both team total salary as well as individual
    player breakdowns

    @param **season** (*str*): String of season in YYYY-ZZZZ
    format

    Attributes:

        **totals** (*dict*): Dictionary keyed by NBA
            team ID with a list of salaries and inflation-adjusted salaries
            (followed by team salary URL) as values

        **totals_columns** (*list*): List of column names for historical team
            salary information

        **team_player_salaries** (*dict*): Dictionary keyed by both NBA
            team ID and Hoopshype player ID with values containing
            salary information

        **team_player_columns** (*list*): List of column names for historical
            team-player salary information
    """

    def __init__(self, season='2017-2018'):

        # First, total team salary information is pulled
        team_salaries, column_list = get_historical_team_salary(season)
        self.totals = team_salaries
        self.totals_columns = column_list
        team_player_salary = {}
        for team_id in team_salaries:
            team_url = team_salaries[team_id][-1]
            player_salaries, column_list = get_historical_player_salary(team_url, season)
            team_player_salary[team_id] = player_salaries

        self.team_player_salaries = team_player_salary
        self.team_player_columns = column_list



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Oct 22 19:59:39 2019

@author: patrickmcfarlane

synergy.py contains the Synergy class that
enables API calls for synergy-related endpoints
"""

from .utils import api_call, parse_api_call

class Synergy:
    """ The Synergy class contains all resources needed to use the synergy-
    related API calls. `stats.nba.com <https://stats.nba.com>`_
    has the following league-related API endpoints:

        - **synergyplaytypes**: Season Synergy play type stats by
        player or team

    The Synergy class has the following required parameters:

        @param **headers** (*dict*): Dictionary of request header information
            required by the API. Specifically, the API requires you to declare
            the 'User-Agent' key of the request header dictionary. More information
            can be found `here <https://stackoverflow.com/questions/46781563/
            how-to-obtain-a-json-response-from-the-stats-nba-com-api>`_ and
            an example request header dictionary can be found in the __init__.py
            file in the tests folder of this module.

        @param **league_id** (*str*): LeagueID in the API. String of a \
            two-digit number corresponding to the league. '00' is the NBA, \
            '10' is the WNBA, '01' is the ABA, and '20' is the G-League. \
            Note that Synergy statistics are only available for the NBA

        @param **season_year** (*str*): SeasonYear in the API. String of a two-year \
            season in a YYYY-ZZ format, where the ZZ are the last two \
            digits of the following year. For example, '2017-18' is a valid \
            value of **season_year** and represents the 2017-18 NBA season.

        @param **season_type** (*str*): SeasonType in the API. String \
            indicating the type of season for data to be returned. \
            Valid values include:

                - 'Regular Season', 'Pre Season', 'Playoffs', 'All Star'

        @param **per_mode** (*str*): PerMode in the API. String indicating \
            the type of rate stats to be returned. Valid values include:

                - 'Totals', 'PerGame', 'MinutesPer', 'Per48', 'Per40', \
                'Per36', 'PerMinute', 'PerPossession', 'PerPlay', \
                'Per100Possessions', 'Per100Plays'

        @param **player_or_team** (*str*): PlayerOrTeam in the API. String \
            indicating whether to return data for players ('P') or teams \
            ('T')

        @param **play_type** (*str*): PlayType in the API. String \
            indicating the type of play as defined by Synergy. Valid \
            values include:

                - 'Cut', 'Handoff', 'Isolation', 'Misc', 'OffScreen', \
                'Postup', 'PRBallHandler', 'PRRollman', 'OffRebound', \
                'Spotup', 'Transition'

        @param **type_grouping** (*str*): TypeGrouping in the API. String \
            indicating the side of the ball for the statistics to be returned. \
            One of 'offensive' or 'defensive'

    Attributes:

        **api_resp** (*dict*): JSON object of the API response. The API \
            response has three keys. The 'resource' key describes the type of \
            response returned (the endpoint in this instance). The 'parameters' \
            key describes the parameters provided in the API call. The \
            'resultSets' key contains the data returned in the API call.

        **data** (*dict*): A dictionary of response names. Each response \
            name is a key to a list of dictionaries containing the \
            corresponding data.

    """

    def __init__(self, headers, endpoint='synergyplaytypes',
                 league_id='00', season_year='2018-19',
                 season_type='Regular Season', per_mode='PerGame',
                 player_or_team='P', play_type='Cut',
                 type_grouping='offensive'):

        # Controlling the parameters depending on the endpoint
        params = {'LeagueID': league_id,
                  'SeasonYear': season_year,
                  'SeasonType': season_type,
                  'PerMode': per_mode,
                  'PlayerOrTeam': player_or_team,
                  'PlayType': play_type,
                  'TypeGrouping': type_grouping}

        self.api_resp = api_call(endpoint=endpoint,
                                 params=params,
                                 headers=headers)

        # Storing the API response in a dictionary called data
        # The results can come in different formats, namely a
        # dictionary keyed by either resultSets or resultSet
        self.data = parse_api_call(self.api_resp)




#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Thu Oct 11 19:01:08 2018

@author: patrickmcfarlane

leaderboard.py contains the LeaderBoard class that
enables API calls for leader board endpoints
"""

from .utils import api_call, parse_api_call

class LeaderBoard:
    """ The LeaderBoard class contains all resources needed to use the
    leader board API calls. `stats.nba.com <https://stats.nba.com>`_
    has the following leader board API endpoints:

        - **homepageleaders**: Top 5 leaders in a number of statistical \
        categories.
        - **homepagev2**: Groups of top 5 leaders in statistical categories \
        related to a given concept.
        - **leaderstiles**: Top 5 leaders in a number of statistical \
        categories, some included in 'homepageleaders' and some \
        not.
        - **leagueleaders**: Longer list of league leaders in a number \
        of statistical categories.

    The LeaderBoard class has the following required parameters:

        @param **headers** (*dict*): Dictionary of request header information
            required by the API. Specifically, the API requires you to declare
            the 'User-Agent' key of the request header dictionary. More information
            can be found `here <https://stackoverflow.com/questions/46781563/
            how-to-obtain-a-json-response-from-the-stats-nba-com-api>`_ and
            an example request header dictionary can be found in the __init__.py
            file in the tests folder of this module.

        @param **league_id** (*str*): LeagueID in the API. String of a \
            two-digit number corresponding to the league. '00' is the NBA, \
            '10' is the WNBA, '01' is the ABA, and '20' is the G-League.

        @param **stat_category** (*str*): StatCategory in the API. String \
            corresponding to the **stat_category** desired in the API \
            response. Valid values include:

                - 'Points', 'Rebounds', 'Assists', 'Defense', \
                'Playmaking', 'Efficiency', 'Fast Break','Scoring Breakdown'

            The stat_category parameter is only required by the \
            'homepageleaders' endpoint.
        
        @param **stat_category_ll** (*str*): StatCategory in the API. String \
            corresponding to the **stat_category** desired in the API response. \
            Valid values include:

                - 'MIN', 'FGM', 'FGA', 'FG_PCT', 'FG3M', 'FG3A', 'FG3_PCT' \
                'FTM', 'FTA', 'FT_PCT', 'OREB', 'DREB', 'REB', 'AST' \
                'STL', 'BLK', 'TOV', 'PTS', 'EFF'

            The **stat_category_ll** parameter is only required by the \
            'leagueleaders' endpoint.

        @param **stat_type** (*str*): StatType in the API. String corresponding \
            to the **stat_type** desired in the API response. Valid values \
            include:

                - 'Traditional', 'Advanced', 'Tracking'

            The **stat_type** parameter is only required by the 'homepagev2' \
            endpoint.

        @param **stat** (*str*): Stat in the API. String corresponding \
            to the **stat** desired in the API response. Valid values \
            include:

                - 'PTS', 'REB', 'AST', 'FG_PCT', 'FT_PCT', 'FG3_PCT' \
                'STL', 'BLK'

            The **stat** parameter is only required by the 'leaderstiles' \
            endpoint.

        @param **season** (*str*): Season in the API. String of a two-year \
            season in a YYYY-ZZ format, where the ZZ are the last two \
            digits of the following year. For example, '2017-18' is a valid \
            value of **season** and represents the 2017-18 NBA season.

        @param **season_type** (*str*): SeasonType in the API. String \
            indicating the type of season for which data is desired. \
            Valid values include:

                - 'Regular Season', 'Pre Season', 'Playoffs'

        @param **player_or_team** (*str*): PlayerOrTeam in the API. String \
            indicating whether data returned is for 'Player' or 'Team' \
            leaders.

        @param **game_scope** (*str*): GameScope in the API. String \
            indicating the period of time for which data is desired. \
            Valid values include:

                - 'Season', 'Last 10', 'Yesterday', 'Finals'

        @param **player_scope** (*str*): PlayerScope in the API. String \
            indicating the type of players for which data is desired. \
            Valid values include:

                - 'All Players', 'Rookies'

        @param **per_mode** (*str*): PerMode in the API. String \
            indicating the rate of the statistics to be returned. \
            Valid values include:

                - 'Totals', 'PerGame', 'Per48'

            The **per_mode** parameter is only required by the 'leagueleaders' \
            endpoint.

        @param **scope** (*str*): Scope in the API. String indicating \
            the type of players for which data is desired. This is \
            nearly identical to **player_scope** above, but for the \
            'leagueleaders' endpoint. Valid values include:

                - 'S' (All players), 'Rookies'

    Attributes:

        **api_resp** (*dict*): JSON object of the API response. The API \
            response has three keys. The 'resource' key describes the type of \
            response returned (the endpoint in this instance). The 'parameters' \
            key describes the parameters provided in the API call. The \
            'resultSets' key contains the data returned in the API call.

        **data** (*dict*): A dictionary of response names. Each response \
        name is a key to a list of dictionaries containing the \
        corresponding data.
    """

    def __init__(self, headers, endpoint='homepageleaders',
                 league_id='00', stat_category='Points',
                 stat_category_ll='PTS',
                 stat_type='Tracking', stat='PTS',
                 season='2017-18', season_type='Regular Season',
                 player_or_team='Player', game_scope='Season',
                 player_scope='All Players', per_mode='PerGame',
                 scope='S'):

        # Controlling the parameters depending on the endpoint
        params = {'LeagueID': league_id,
                  'Season': season,
                  'SeasonType': season_type,
                  'PlayerOrTeam': player_or_team,
                  'GameScope': game_scope,
                  'PlayerScope': player_scope}

        if endpoint == 'homepageleaders':
            params ['StatCategory'] = stat_category
        elif endpoint == 'homepagev2':
            params['StatType'] = stat_type
        elif endpoint == 'leaderstiles':
            params['Stat'] = stat
        elif endpoint == 'leagueleaders':
            params['StatCategory'] = stat_category_ll
            params['PerMode'] = per_mode
            params['Scope'] = scope

        self.api_resp = api_call(endpoint=endpoint,
                                 params=params,
                                 headers=headers)

        # Storing the API response in a dictionary called data
        # The results can come in different formats, namely a
        # dictionary keyed by either resultSets or resultSet
        self.data = parse_api_call(self.api_resp)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Oct  8 20:08:30 2018

@author: patrickmcfarlane

draft.py contains the Draft class that
enables API calls for draft related endpoints
"""

from .utils import api_call, parse_api_call

class Draft:
    """ The Draft class contains all resources needed to use the draft-
    related API calls. `stats.nba.com <https://stats.nba.com>`_
    has the following draft-related API endpoints:

        - **draftcombinestats**: Draft combine drill results and measurement \
        data for players.
        - **drafthistory**: Draft results detailing metadata of draftees \
        by season.

    The Draft class has the following required parameters:

        @param **headers** (*dict*): Dictionary of request header information
            required by the API. Specifically, the API requires you to declare
            the 'User-Agent' key of the request header dictionary. More information
            can be found `here <https://stackoverflow.com/questions/46781563/
            how-to-obtain-a-json-response-from-the-stats-nba-com-api>`_ and
            an example request header dictionary can be found in the __init__.py
            file in the tests folder of this module.

        @param **league_id** (*str*): LeagueID in the API. String of a \
            two-digit number corresponding to the league. '00' is the NBA, \
            '10' is the WNBA, '01' is the ABA, and '20' is the G-League. \
            Draft data is only available for the NBA.

        @param **season_year** (*str*): SeasonYear in the API. String of \
            a two-year season year in a YYYY-ZZ format, where the ZZ are the \
            last two digits of the following year. For example, '2017-18' is \
            a valid value of **season_year** and represents the 2017-18 NBA season. \
            'All Time' is a valid value for the 'draftcombinestats' endpoint.

    Attributes:

        **api_resp** (*dict*): JSON object of the API response. The API \
            response has three keys. The 'resource' key describes the type of \
            response returned (the endpoint in this instance). The 'parameters' \
            key describes the parameters provided in the API call. The \
            'resultSets' key contains the data returned in the API call.

        **data** (*dict*): A dictionary of response names. Each response \
            name is a key to a list of dictionaries containing the corresponding \
            data.
    """

    def __init__(self, headers, endpoint='draftcombinestats',
                 league_id='00', season_year='2017-18'):

        # Controlling the parameters depending on the endpoint
        if endpoint in ['drafthistory']:
            params = {'LeagueID': league_id}
        else:
            params = {'LeagueID': league_id,
                      'SeasonYear': season_year}

        self.api_resp = api_call(endpoint=endpoint,
                                 params=params,
                                 headers=headers)

        # Storing the API response in a dictionary called data
        # The results can come in different formats, namely a
        # dictionary keyed by either resultSets or resultSet
        self.data = parse_api_call(self.api_resp)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Dec 17 20:43:34 2018

@author: patrickmcfarlane

test_boxscore.py

This function contains the tests for
functions in the boxscore.py file
"""

from .__init__ import HEADERS
from ..boxscore import BoxScore

def test_boxscore_advanced():
    """ tests the boxscoreadvancedv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS, game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'PlayerStats' in table_names
    assert 'TeamStats' in table_names

    example_player_stats = example_boxscore.data['PlayerStats'][0]
    example_team_stats = example_boxscore.data['TeamStats'][0]

    assert list(example_player_stats.keys()) == ['GAME_ID',
                                                 'TEAM_ID',
                                                 'TEAM_ABBREVIATION',
                                                 'TEAM_CITY',
                                                 'PLAYER_ID',
                                                 'PLAYER_NAME',
                                                 'START_POSITION',
                                                 'COMMENT',
                                                 'MIN',
                                                 'E_OFF_RATING',
                                                 'OFF_RATING',
                                                 'E_DEF_RATING',
                                                 'DEF_RATING',
                                                 'E_NET_RATING',
                                                 'NET_RATING',
                                                 'AST_PCT',
                                                 'AST_TOV',
                                                 'AST_RATIO',
                                                 'OREB_PCT',
                                                 'DREB_PCT',
                                                 'REB_PCT',
                                                 'TM_TOV_PCT',
                                                 'EFG_PCT',
                                                 'TS_PCT',
                                                 'USG_PCT',
                                                 'E_USG_PCT',
                                                 'E_PACE',
                                                 'PACE',
                                                 'PIE']

    assert list(example_team_stats.keys()) == ['GAME_ID',
                                               'TEAM_ID',
                                               'TEAM_NAME',
                                               'TEAM_ABBREVIATION',
                                               'TEAM_CITY',
                                               'MIN',
                                               'E_OFF_RATING',
                                               'OFF_RATING',
                                               'E_DEF_RATING',
                                               'DEF_RATING',
                                               'E_NET_RATING',
                                               'NET_RATING',
                                               'AST_PCT',
                                               'AST_TOV',
                                               'AST_RATIO',
                                               'OREB_PCT',
                                               'DREB_PCT',
                                               'REB_PCT',
                                               'E_TM_TOV_PCT',
                                               'TM_TOV_PCT',
                                               'EFG_PCT',
                                               'TS_PCT',
                                               'USG_PCT',
                                               'E_USG_PCT',
                                               'E_PACE',
                                               'PACE',
                                               'PIE']

def test_boxscore_four_factors():
    """ tests the boxscorefourfactorsv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS,
                                endpoint='boxscorefourfactorsv2',
                                game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'sqlPlayersFourFactors' in table_names
    assert 'sqlTeamsFourFactors' in table_names

    example_player_stats = example_boxscore.data['sqlPlayersFourFactors'][0]
    example_team_stats = example_boxscore.data['sqlTeamsFourFactors'][0]

    assert list(example_player_stats.keys()) == ['GAME_ID',
                                                 'TEAM_ID',
                                                 'TEAM_ABBREVIATION',
                                                 'TEAM_CITY',
                                                 'PLAYER_ID',
                                                 'PLAYER_NAME',
                                                 'START_POSITION',
                                                 'COMMENT',
                                                 'MIN',
                                                 'EFG_PCT',
                                                 'FTA_RATE',
                                                 'TM_TOV_PCT',
                                                 'OREB_PCT',
                                                 'OPP_EFG_PCT',
                                                 'OPP_FTA_RATE',
                                                 'OPP_TOV_PCT',
                                                 'OPP_OREB_PCT']

    assert list(example_team_stats.keys()) == ['GAME_ID',
                                               'TEAM_ID',
                                               'TEAM_NAME',
                                               'TEAM_ABBREVIATION',
                                               'TEAM_CITY',
                                               'MIN',
                                               'EFG_PCT',
                                               'FTA_RATE',
                                               'TM_TOV_PCT',
                                               'OREB_PCT',
                                               'OPP_EFG_PCT',
                                               'OPP_FTA_RATE',
                                               'OPP_TOV_PCT',
                                               'OPP_OREB_PCT']

def test_boxscore_misc():
    """ tests the boxscoremiscv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS,
                                endpoint='boxscoremiscv2',
                                game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'sqlPlayersMisc' in table_names
    assert 'sqlTeamsMisc' in table_names

    example_player_stats = example_boxscore.data['sqlPlayersMisc'][0]
    example_team_stats = example_boxscore.data['sqlTeamsMisc'][0]

    assert list(example_player_stats.keys()) == ['GAME_ID',
                                                 'TEAM_ID',
                                                 'TEAM_ABBREVIATION',
                                                 'TEAM_CITY',
                                                 'PLAYER_ID',
                                                 'PLAYER_NAME',
                                                 'START_POSITION',
                                                 'COMMENT',
                                                 'MIN',
                                                 'PTS_OFF_TOV',
                                                 'PTS_2ND_CHANCE',
                                                 'PTS_FB',
                                                 'PTS_PAINT',
                                                 'OPP_PTS_OFF_TOV',
                                                 'OPP_PTS_2ND_CHANCE',
                                                 'OPP_PTS_FB',
                                                 'OPP_PTS_PAINT',
                                                 'BLK',
                                                 'BLKA',
                                                 'PF',
                                                 'PFD']

    assert list(example_team_stats.keys()) == ['GAME_ID',
                                               'TEAM_ID',
                                               'TEAM_NAME',
                                               'TEAM_ABBREVIATION',
                                               'TEAM_CITY',
                                               'MIN',
                                               'PTS_OFF_TOV',
                                               'PTS_2ND_CHANCE',
                                               'PTS_FB',
                                               'PTS_PAINT',
                                               'OPP_PTS_OFF_TOV',
                                               'OPP_PTS_2ND_CHANCE',
                                               'OPP_PTS_FB',
                                               'OPP_PTS_PAINT',
                                               'BLK',
                                               'BLKA',
                                               'PF',
                                               'PFD']

def test_boxscore_player_track():
    """ tests the boxscoremiscv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS,
                                endpoint='boxscoreplayertrackv2',
                                game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'PlayerStats' in table_names
    assert 'TeamStats' in table_names

    example_player_stats = example_boxscore.data['PlayerStats'][0]
    example_team_stats = example_boxscore.data['TeamStats'][0]

    assert list(example_player_stats.keys()) == ['GAME_ID',
                                                 'TEAM_ID',
                                                 'TEAM_ABBREVIATION',
                                                 'TEAM_CITY',
                                                 'PLAYER_ID',
                                                 'PLAYER_NAME',
                                                 'START_POSITION',
                                                 'COMMENT',
                                                 'MIN',
                                                 'SPD',
                                                 'DIST',
                                                 'ORBC',
                                                 'DRBC',
                                                 'RBC',
                                                 'TCHS',
                                                 'SAST',
                                                 'FTAST',
                                                 'PASS',
                                                 'AST',
                                                 'CFGM',
                                                 'CFGA',
                                                 'CFG_PCT',
                                                 'UFGM',
                                                 'UFGA',
                                                 'UFG_PCT',
                                                 'FG_PCT',
                                                 'DFGM',
                                                 'DFGA',
                                                 'DFG_PCT']

    assert list(example_team_stats.keys()) == ['GAME_ID',
                                               'TEAM_ID',
                                               'TEAM_NAME',
                                               'TEAM_ABBREVIATION',
                                               'TEAM_CITY',
                                               'MIN',
                                               'DIST',
                                               'ORBC',
                                               'DRBC',
                                               'RBC',
                                               'TCHS',
                                               'SAST',
                                               'FTAST',
                                               'PASS',
                                               'AST',
                                               'CFGM',
                                               'CFGA',
                                               'CFG_PCT',
                                               'UFGM',
                                               'UFGA',
                                               'UFG_PCT',
                                               'FG_PCT',
                                               'DFGM',
                                               'DFGA',
                                               'DFG_PCT']
    
def test_boxscore_scoring():
    """ tests the boxscorescoringv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS,
                                endpoint='boxscorescoringv2',
                                game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'sqlPlayersScoring' in table_names
    assert 'sqlTeamsScoring' in table_names

    example_player_stats = example_boxscore.data['sqlPlayersScoring'][0]
    example_team_stats = example_boxscore.data['sqlTeamsScoring'][0]

    assert list(example_player_stats.keys()) == ['GAME_ID',
                                                 'TEAM_ID',
                                                 'TEAM_ABBREVIATION',
                                                 'TEAM_CITY',
                                                 'PLAYER_ID',
                                                 'PLAYER_NAME',
                                                 'START_POSITION',
                                                 'COMMENT',
                                                 'MIN',
                                                 'PCT_FGA_2PT',
                                                 'PCT_FGA_3PT',
                                                 'PCT_PTS_2PT',
                                                 'PCT_PTS_2PT_MR',
                                                 'PCT_PTS_3PT',
                                                 'PCT_PTS_FB',
                                                 'PCT_PTS_FT',
                                                 'PCT_PTS_OFF_TOV',
                                                 'PCT_PTS_PAINT',
                                                 'PCT_AST_2PM',
                                                 'PCT_UAST_2PM',
                                                 'PCT_AST_3PM',
                                                 'PCT_UAST_3PM',
                                                 'PCT_AST_FGM',
                                                 'PCT_UAST_FGM']

    assert list(example_team_stats.keys()) == ['GAME_ID',
                                               'TEAM_ID',
                                               'TEAM_NAME',
                                               'TEAM_ABBREVIATION',
                                               'TEAM_CITY',
                                               'MIN',
                                               'PCT_FGA_2PT',
                                               'PCT_FGA_3PT',
                                               'PCT_PTS_2PT',
                                               'PCT_PTS_2PT_MR',
                                               'PCT_PTS_3PT',
                                               'PCT_PTS_FB',
                                               'PCT_PTS_FT',
                                               'PCT_PTS_OFF_TOV',
                                               'PCT_PTS_PAINT',
                                               'PCT_AST_2PM',
                                               'PCT_UAST_2PM',
                                               'PCT_AST_3PM',
                                               'PCT_UAST_3PM',
                                               'PCT_AST_FGM',
                                               'PCT_UAST_FGM']

def test_boxscore_summary():
    """ tests the boxscoresummaryv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS,
                                endpoint='boxscoresummaryv2',
                                game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'GameSummary' in table_names
    assert 'OtherStats' in table_names
    assert 'Officials' in table_names
    assert 'InactivePlayers' in table_names
    assert 'GameInfo' in table_names
    assert 'LineScore' in table_names
    assert 'LastMeeting' in table_names
    assert 'SeasonSeries' in table_names
    assert 'AvailableVideo' in table_names

    example_game_summary = example_boxscore.data['GameSummary'][0]
    example_other_stats = example_boxscore.data['OtherStats'][0]
    example_officials = example_boxscore.data['Officials'][0]
    example_inactive_players = example_boxscore.data['InactivePlayers'][0]
    example_game_info = example_boxscore.data['GameInfo'][0]
    example_line_score = example_boxscore.data['LineScore'][0]
    example_last_meeting = example_boxscore.data['LastMeeting'][0]
    example_season_series = example_boxscore.data['SeasonSeries'][0]
    example_available_video = example_boxscore.data['AvailableVideo'][0]

    assert list(example_game_summary.keys()) == ['GAME_DATE_EST',
                                                 'GAME_SEQUENCE',
                                                 'GAME_ID',
                                                 'GAME_STATUS_ID',
                                                 'GAME_STATUS_TEXT',
                                                 'GAMECODE',
                                                 'HOME_TEAM_ID',
                                                 'VISITOR_TEAM_ID',
                                                 'SEASON',
                                                 'LIVE_PERIOD',
                                                 'LIVE_PC_TIME',
                                                 'NATL_TV_BROADCASTER_ABBREVIATION',
                                                 'LIVE_PERIOD_TIME_BCAST',
                                                 'WH_STATUS']

    assert list(example_other_stats.keys()) == ['LEAGUE_ID',
                                                'TEAM_ID',
                                                'TEAM_ABBREVIATION',
                                                'TEAM_CITY',
                                                'PTS_PAINT',
                                                'PTS_2ND_CHANCE',
                                                'PTS_FB',
                                                'LARGEST_LEAD',
                                                'LEAD_CHANGES',
                                                'TIMES_TIED',
                                                'TEAM_TURNOVERS',
                                                'TOTAL_TURNOVERS',
                                                'TEAM_REBOUNDS',
                                                'PTS_OFF_TO']

    assert list(example_officials.keys()) == ['OFFICIAL_ID',
                                              'FIRST_NAME',
                                              'LAST_NAME',
                                              'JERSEY_NUM']

    assert list(example_inactive_players.keys()) == ['PLAYER_ID',
                                                     'FIRST_NAME',
                                                     'LAST_NAME',
                                                     'JERSEY_NUM',
                                                     'TEAM_ID',
                                                     'TEAM_CITY',
                                                     'TEAM_NAME',
                                                     'TEAM_ABBREVIATION']

    assert list(example_game_info.keys()) == ['GAME_DATE',
                                              'ATTENDANCE',
                                              'GAME_TIME']

    assert list(example_line_score.keys()) == ['GAME_DATE_EST',
                                               'GAME_SEQUENCE',
                                               'GAME_ID',
                                               'TEAM_ID',
                                               'TEAM_ABBREVIATION',
                                               'TEAM_CITY_NAME',
                                               'TEAM_NICKNAME',
                                               'TEAM_WINS_LOSSES',
                                               'PTS_QTR1',
                                               'PTS_QTR2',
                                               'PTS_QTR3',
                                               'PTS_QTR4',
                                               'PTS_OT1',
                                               'PTS_OT2',
                                               'PTS_OT3',
                                               'PTS_OT4',
                                               'PTS_OT5',
                                               'PTS_OT6',
                                               'PTS_OT7',
                                               'PTS_OT8',
                                               'PTS_OT9',
                                               'PTS_OT10',
                                               'PTS']

    assert list(example_last_meeting.keys()) == ['GAME_ID',
                                                 'LAST_GAME_ID',
                                                 'LAST_GAME_DATE_EST',
                                                 'LAST_GAME_HOME_TEAM_ID',
                                                 'LAST_GAME_HOME_TEAM_CITY',
                                                 'LAST_GAME_HOME_TEAM_NAME',
                                                 'LAST_GAME_HOME_TEAM_ABBREVIATION',
                                                 'LAST_GAME_HOME_TEAM_POINTS',
                                                 'LAST_GAME_VISITOR_TEAM_ID',
                                                 'LAST_GAME_VISITOR_TEAM_CITY',
                                                 'LAST_GAME_VISITOR_TEAM_NAME',
                                                 'LAST_GAME_VISITOR_TEAM_CITY1',
                                                 'LAST_GAME_VISITOR_TEAM_POINTS']

    assert list(example_season_series.keys()) == ['GAME_ID',
                                                  'HOME_TEAM_ID',
                                                  'VISITOR_TEAM_ID',
                                                  'GAME_DATE_EST',
                                                  'HOME_TEAM_WINS',
                                                  'HOME_TEAM_LOSSES',
                                                  'SERIES_LEADER']

    assert list(example_available_video.keys()) == ['GAME_ID',
                                                    'VIDEO_AVAILABLE_FLAG',
                                                    'PT_AVAILABLE',
                                                    'PT_XYZ_AVAILABLE',
                                                    'WH_STATUS',
                                                    'HUSTLE_STATUS',
                                                    'HISTORICAL_STATUS']

def test_boxscore_traditional():
    """ tests the boxscoretraditionalv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS,
                                endpoint='boxscoretraditionalv2',
                                game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'PlayerStats' in table_names
    assert 'TeamStats' in table_names
    assert 'TeamStarterBenchStats' in table_names

    example_player_stats = example_boxscore.data['PlayerStats'][0]
    example_team_stats = example_boxscore.data['TeamStats'][0]
    example_team_bench_stats = example_boxscore.data['TeamStarterBenchStats'][0]

    assert list(example_player_stats.keys()) == ['GAME_ID',
                                                 'TEAM_ID',
                                                 'TEAM_ABBREVIATION',
                                                 'TEAM_CITY',
                                                 'PLAYER_ID',
                                                 'PLAYER_NAME',
                                                 'START_POSITION',
                                                 'COMMENT',
                                                 'MIN',
                                                 'FGM',
                                                 'FGA',
                                                 'FG_PCT',
                                                 'FG3M',
                                                 'FG3A',
                                                 'FG3_PCT',
                                                 'FTM',
                                                 'FTA',
                                                 'FT_PCT',
                                                 'OREB',
                                                 'DREB',
                                                 'REB',
                                                 'AST',
                                                 'STL',
                                                 'BLK',
                                                 'TO',
                                                 'PF',
                                                 'PTS',
                                                 'PLUS_MINUS']

    assert list(example_team_stats.keys()) == ['GAME_ID',
                                              'TEAM_ID',
                                              'TEAM_NAME',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_CITY',
                                              'MIN',
                                              'FGM',
                                              'FGA',
                                              'FG_PCT',
                                              'FG3M',
                                              'FG3A',
                                              'FG3_PCT',
                                              'FTM',
                                              'FTA',
                                              'FT_PCT',
                                              'OREB',
                                              'DREB',
                                              'REB',
                                              'AST',
                                              'STL',
                                              'BLK',
                                              'TO',
                                              'PF',
                                              'PTS',
                                              'PLUS_MINUS']

    assert list(example_team_bench_stats.keys()) == ['GAME_ID',
                                                     'TEAM_ID',
                                                     'TEAM_NAME',
                                                     'TEAM_ABBREVIATION',
                                                     'TEAM_CITY',
                                                     'STARTERS_BENCH',
                                                     'MIN',
                                                     'FGM',
                                                     'FGA',
                                                     'FG_PCT',
                                                     'FG3M',
                                                     'FG3A',
                                                     'FG3_PCT',
                                                     'FTM',
                                                     'FTA',
                                                     'FT_PCT',
                                                     'OREB',
                                                     'DREB',
                                                     'REB',
                                                     'AST',
                                                     'STL',
                                                     'BLK',
                                                     'TO',
                                                     'PF',
                                                     'PTS']

def test_boxscore_usage():
    """ tests the boxscoretraditionalv2 endpoint of the Boxscore class
    """

    example_boxscore = BoxScore(headers=HEADERS,
                                endpoint='boxscoreusagev2',
                                game_id='0021500002')

    table_names = example_boxscore.data.keys()

    assert 'sqlPlayersUsage' in table_names
    assert 'sqlTeamsUsage' in table_names

    example_player_stats = example_boxscore.data['sqlPlayersUsage'][0]
    example_team_stats = example_boxscore.data['sqlTeamsUsage'][0]

    assert list(example_player_stats.keys()) == ['GAME_ID',
                                                 'TEAM_ID',
                                                 'TEAM_ABBREVIATION',
                                                 'TEAM_CITY',
                                                 'PLAYER_ID',
                                                 'PLAYER_NAME',
                                                 'START_POSITION',
                                                 'COMMENT',
                                                 'MIN',
                                                 'USG_PCT',
                                                 'PCT_FGM',
                                                 'PCT_FGA',
                                                 'PCT_FG3M',
                                                 'PCT_FG3A',
                                                 'PCT_FTM',
                                                 'PCT_FTA',
                                                 'PCT_OREB',
                                                 'PCT_DREB',
                                                 'PCT_REB',
                                                 'PCT_AST',
                                                 'PCT_TOV',
                                                 'PCT_STL',
                                                 'PCT_BLK',
                                                 'PCT_BLKA',
                                                 'PCT_PF',
                                                 'PCT_PFD',
                                                 'PCT_PTS']

    assert list(example_team_stats.keys()) == ['GAME_ID',
                                              'TEAM_ID',
                                              'TEAM_NAME',
                                              'TEAM_ABBREVIATION',
                                              'TEAM_CITY',
                                              'MIN',
                                              'USG_PCT',
                                              'PCT_FGM',
                                              'PCT_FGA',
                                              'PCT_FG3M',
                                              'PCT_FG3A',
                                              'PCT_FTM',
                                              'PCT_FTA',
                                              'PCT_OREB',
                                              'PCT_DREB',
                                              'PCT_REB',
                                              'PCT_AST',
                                              'PCT_TOV',
                                              'PCT_STL',
                                              'PCT_BLK',
                                              'PCT_BLKA',
                                              'PCT_PF',
                                              'PCT_PFD',
                                              'PCT_PTS']



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sat Dec 22 12:46:48 2018

@author: patrickmcfarlane

test_image.py

This function contains the tests for
functions in the image.py file
"""

import PIL
from ..image import Headshot, Logo

def test_headshot():
    """ tests the Headshot class
    """

    example_wnba_headshot = Headshot()
    example_nba_headshot = Headshot(league='NBA',
                                    player_id='2544',
                                    team_id='1610612747',
                                    season='2018')

    assert type(example_wnba_headshot.image) == PIL.PngImagePlugin.PngImageFile
    assert type(example_nba_headshot.image) == PIL.PngImagePlugin.PngImageFile

def test_logo():
    """ tests the Logo class
    """

    example_wnba_logo = Logo()
    example_nba_logo = Logo(league='NBA',
                            team_id='1610612755',
                            season_year='2018-19')

    assert type(example_wnba_logo.image) == PIL.PngImagePlugin.PngImageFile
    assert type(example_nba_logo.image) == PIL.PngImagePlugin.PngImageFile



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Mon Oct  8 13:36:55 2018

@author: patrickmcfarlane

boxscore.py contains the BoxScore class that
enables API calls for boxscore related endpoints
"""

from .utils import api_call, parse_api_call

class BoxScore:
    """
    The BoxScore class contains all resources needed to use the boxscore-
    related API calls. `stats.nba.com <https://stats.nba.com>`_
    has the following boxscore-related API endpoints:

        - **boxscoreadvancedv2**: Game boxscore containing several advanced \
        statistics
        - **boxscorefourfactorsv2**: Game boxscore containing statistics related \
        to the Four Factors, for team and opponent
        - **boxscoremiscv2**: Game boxscore containing points scored by type \
        of change (paint, fastbreak, etc.) for team and opponent
        - **boxscoreplayertrackv2**: Game boxscore containing aggregated player \
        tracking statistics
        - **boxscorescoringv2**: Game boxscore containing percentage scoring \
        statistics broken down by shot type.
        - **boxscoresummaryv2**: Game boxscore containing a summary of a \
        particular matchup (including game metadata and results)
        - **boxscoretraditionalv2**: Game boxscore containing basic statistics
        - **boxscoreusagev2**: Game boxscore containing usage statistics \
        and percentage

    The BoxScore class has the following required parameters:

        @param **headers** (*dict*): Dictionary of request header information
            required by the API. Specifically, the API requires you to declare
            the 'User-Agent' key of the request header dictionary. More information
            can be found `here <https://stackoverflow.com/questions/46781563/
            how-to-obtain-a-json-response-from-the-stats-nba-com-api>`_ and
            an example request header dictionary can be found in the __init__.py
            file in the tests folder of this module.

        @param **game_id** (*str*): GameID in the API. 10-digit string that represents \
            a unique game. The format is two leading zeroes, followed by a \
            season indicator number ('1' for preseason, \
            '2' for regular season, '4' for the post-season), \
            then the trailing digits of the season in which the game \
            took place (e.g. '17' for the 2017-18 season). The following \
            5 digits increment from '00001' in order as the season progresses. \
            For example, '0021600001' is the **game_id** of the first game of the \
            2016-17 NBA regular season.

        @param **range_type** (*str*): RangeType in the API. **range_type** controls the \
            type of boxscore that is returned. If using the **start_period** and \
            **end_period** parameters (defined below), **range_type** should have a value \
            of '0' (DNP players included) or '1' (DNP players excluded). With \
            a **range_type** value of '2', the **start_range** and **end_range** values can be \
            used to return a boxscore from a customized subset of the given game.

        @param **start_period** (*str*): StartPeriod in the API. String of an integer \
            that corresponds to the period for which the boxscore begins.

        @param **end_period** (str): EndPeriod in the API. String of an integer that \
            corresponds to the period for which the boxscore ends (Overtime \
            increments logically, e.g. '5' is the first overtime period).

        @param **start_range** (*str*): StartRange in the API. String of an integer \
            that corresponds to the tenths of seconds that have elapsed in the \
            game for which the boxscore begins. Valid when **range_type** ='2'.

        @param **end_range** (*str*) : EndRange in the API. String of an integer \
            that corresponds to the tenths of seconds that have elapsed in the \
            game for which the boxscore ends. Valid when **range_type** ='2'.
        
    Attributes:

        - **api_resp** (*dict*): JSON object of the API response. The API response \
            has three keys. The 'resource' key describes the type of \
            response returned ('boxscore' in this instance). The 'parameters' \
            key describes the parameters provided in the API call. The \
            'resultSets' key contains the data returned in the API call.

        - **data** (*dict*): A dictionary of response names. Each response name is a \
            key to a list of dictionaries containing the corresponding data.
    """

    def __init__(self, headers, game_id, endpoint='boxscoreadvancedv2',
                 range_type='1', start_period='0', end_period='10',
                 start_range='0', end_range='0'):

        # Controlling the parameters depending on the endpoint
        if endpoint in ['boxscoreplayertrackv2', 'boxscoresummaryv2']:
            params = {'GameID': game_id}
        else:
            params = {'GameID': game_id,
                      'RangeType': range_type,
                      'StartPeriod': start_period,
                      'EndPeriod': end_period,
                      'StartRange': start_range,
                      'EndRange': end_range}

        self.api_resp = api_call(endpoint=endpoint,
                                 params=params,
                                 headers=headers)

        # Storing the API response in a dictionary called data
        # The results can come in different formats, namely a
        # dictionary keyed by either resultSets or resultSet
        self.data = parse_api_call(self.api_resp)
                



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Oct 21 15:41:34 2018

@author: patrickmcfarlane

setup.py

Standard setup.py script for the py_ball package.
"""

import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="py_ball",
    version="1.0.5",
    author="Patrick McFarlane",
    author_email="patmcfarla@gmail.com",
    description="Python API wrapper for stats.nba.com with a focus on \
                 NBA and WNBA applications",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/basketballrelativity/py_ball",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
